#
# spec file for package yast2-storage-ng
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-storage-ng
Version:        4.3.56
Release:        3.12.1
Summary:        YaST2 - Storage Configuration
License:        GPL-2.0-only OR GPL-3.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-storage-ng

Source:         %{name}-%{version}.tar.bz2

# UF_PMEM and UF_NVME
BuildRequires:  libstorage-ng-ruby >= 4.3.30
BuildRequires:  update-desktop-files
# Yast::Kernel.propose_hibernation?
BuildRequires:  yast2 >= 4.3.41
BuildRequires:  yast2-devtools >= 4.2.2
# for AbortException and handle direct abort
BuildRequires:  yast2-ruby-bindings >= 4.0.6
# yast2-xml dependency is added by yast2 but ignored in the
# openSUSE:Factory project config
BuildRequires:  yast2-xml
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
# communicate with udisks
BuildRequires:  rubygem(%{rb_default_ruby_abi}:ruby-dbus)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
# speed up the tests in SLE15-SP1+ or TW
%if 0%{?sle_version} >= 150100 || 0%{?suse_version} > 1500
BuildRequires:  rubygem(%{rb_default_ruby_abi}:parallel_tests)
%endif

# findutils for xargs
Requires:       findutils
# UF_PMEM and UF_NVME
Requires:       libstorage-ng-ruby >= 4.3.30
# Yast::Kernel.propose_hibernation?
Requires:       yast2 >= 4.3.41
# Y2Packager::Repository
Requires:       yast2-packager >= 3.3.7
# for AbortException and handle direct abort
Requires:       yast2-ruby-bindings >= 4.0.6
# OpenItems for (nested) tables
Requires:       yast2-ycp-ui-bindings >= 4.3.4
# communicate with udisks
Requires:       rubygem(%{rb_default_ruby_abi}:ruby-dbus)
Requires(post): %fillup_prereq

Recommends:     (libyui-qt-graph if libyui-qt)

Obsoletes:      yast2-storage

%description
This package contains the files for YaST2 that handle access to disk
devices during installation and on an installed system.
This YaST2 module uses libstorage-ng.

%prep
%setup -q

%check
rake test:unit

%build

%install
%yast_install
%yast_metainfo

%post
%{fillup_only -ans storage %{name}.common}
%ifarch s390 s390x
%{fillup_only -ans storage %{name}.s390}
%else
%{fillup_only -ans storage %{name}.default}
%endif

%files
%{yast_clientdir}
%{yast_libdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_fillupdir}
%{yast_ybindir}
# agents-scr
%{yast_scrconfdir}
%{yast_icondir}
%license COPYING
%doc README.md

%changelog
* Thu Oct 14 2021 dgonzalez@suse.com
- Fix (un)masking systemd units by using the systemctl --plain
  flag for getting an output without status glyphs (bsc#1191347).
- 4.3.56
* Fri Oct  1 2021 jlopez@suse.com
- Recommend to install libyui-qt-graph package (bsc#1191109) in
  order to offer the View/Device Graphs menu option.
- 4.3.55
* Tue Jun 15 2021 igonzalezsosa@suse.com
- Fix the Comment entry in the desktop file so the tooltip
  in the control center is properly translated (bsc#1187270).
- 4.3.54
* Mon Jun  7 2021 snwint@suse.com
- ensure mount options are not doubled (bsc#1186298)
- 4.3.53
* Fri Jun  4 2021 snwint@suse.com
- try harder matching device names (bsc#1186268)
- 4.3.52
* Thu May 20 2021 kanderssen@suse.com
- Make the 'Change Used Devices' menu item translatable
  (bsc#1185060).
- 4.3.51
* Tue Mar 30 2021 jlopez@suse.com
- Avoid to call private methods over self because it raises an
  exception with ruby < 2.7 (related to bsc#1180723).
- 4.3.50
* Wed Mar 17 2021 jlopez@suse.com
- Round-down the number of physical extends according to the
  stripes of the logical volume (bsc#1180723).
- Add extra validations when creating a striped volume and when
  editing the physical volumes.
- 4.3.49
* Thu Mar 11 2021 dgonzalez@suse.com
- Stop using the question mark icon in the recursive deletion
  confirm dialog (bsc#1183088).
- 4.3.48
* Tue Mar  9 2021 jlopez@suse.com
- Partitioner: allow to define the file system label (bsc#1183220).
- 4.3.47
* Thu Feb 25 2021 ancor@suse.com
- Improved mechanism to detect whether _netdev is needed for a
  given disk: use its driver as extra criterion (bsc#1176140).
- 4.3.46
* Thu Feb 25 2021 ancor@suse.com
- Partitioner: extended the text of the help to cover the new menu
  and the general navigation (related to bsc#1181590).
- 4.3.45
* Fri Feb 19 2021 jlopez@suse.com
- Partitioner: ask for recursively unmounting affected devices when
  deleting a device (bsc#1171310).
- 4.3.44
* Thu Feb 11 2021 ancor@suse.com
- Partitioner: in general, collapse branches of the tables only if
  they contain Btrfs snapshots (related to bsc#1181464).
- 4.3.43
* Thu Feb  4 2021 ancor@suse.com
- Partitioner: stop offering LVM pools as possible base devices
  for bcache devices and for multi-device btrfs (bsc#1170044).
- 4.3.42
* Thu Jan 28 2021 ancor@suse.com
- AutoYaST UI: improved visualization of some partition sections
  in the left tree (related to jsc#SLE-11308).
- 4.3.41
* Mon Jan 25 2021 jlopez@suse.com
- Partitioner: fix typo calling to popup (bsc#1181348).
- 4.3.40
* Fri Jan 22 2021 jlopez@suse.com
- Partitioner: show used devices for MD BIOS RAID (bsc#1181300).
- 4.3.39
* Thu Jan 21 2021 jlopez@suse.com
- Partitioner: properly set subvolume limit when creating a new
  subvolume (bsc#1181205).
- 4.3.38
* Thu Jan 14 2021 ancor@suse.com
- Partitioner: removed warning for too small EFI system partition.
- Proposal: reuse pre-existing EFI partition even if it's small
- Related to bsc#1177358, bsc#1170625 and bsc#1119318.
- 4.3.37
* Tue Jan 12 2021 ancor@suse.com
- Added API methods to get the preferred name to reference a block
  device or its filesystem (jsc#SLE-17081, also related to
  bsc#1177926 and bsc#1169874).
- 4.3.36
* Tue Dec 22 2020 ancor@suse.com
- Partitioner: do not allow to modify the path of Btrfs subvolumes
  (bsc#1180182)
- 4.3.35
* Mon Dec 21 2020 dgonzalez@suse.com
- Storage: pre-generates an UUID for every swap device the
  installer plans to create (related to jsc#SLE-17081, bsc#1169874,
  and bsc#1177926).
- 4.3.34
* Fri Dec 18 2020 igonzalezsosa@suse.com
- AutoYaST: setting the 'quotas' element to 'false' disables
  subvolumes quotas, no matter whether the 'referenced_limit'
  was specified or not (related to jsc#SLE-7742).
- 4.3.33
* Thu Dec 17 2020 ancor@suse.com
- Fixed deletion of dependant devicegraph nodes (bsc#1179590)
- 4.3.32
* Tue Dec 15 2020 jlopez@suse.com
- AutoYaST: added management of tmpfs file systems (jsc#SLE-11308).
- 4.3.31
* Tue Dec 15 2020 ancor@suse.com
- Do not enforce installation of packages that are not strictly
  needed (bsc#1065588).
- Partitioner: improved calculation of which packages need to be
  installed in the running system (bsc#1168077).
* Thu Dec 10 2020 igonzalezsosa@suse.com
- AutoYaST: add support for Btrfs quotas (jsc#SLE-7742).
- 4.3.29
* Thu Dec 10 2020 jlopez@suse.com
- Partitioner: do not show summary when there are no actions to
  perform (bsc#1179829).
- 4.3.28
* Fri Dec  4 2020 jlopez@suse.com
- Fix unit tests (related to jsc#SLE-11308).
- 4.3.27
* Thu Dec  3 2020 ancor@suse.com
- Partitioner: added management of tmpfs file systems (related to
  jsc#SLE-11308).
- 4.3.26
* Wed Dec  2 2020 jlopez@suse.com
- Use Yast::Kernel.propose_hibernation? (related to jsc#SLE-12280).
- 4.3.25
* Thu Nov 26 2020 ancor@suse.com
- Y2Storage wrapper for the new Tmpfs class from libstorage-ng
  (related to jsc#SLE-11308)
* Wed Nov 25 2020 jlopez@suse.com
- Partitioner: improve support for Btrfs subvolumes, related to
  bsc#996598, bsc#1175139, bsc#1161408, bsc#1004783, bsc#1067505.
- Partitioner: add support for Btrfs quotas (jsc#SLE-7742).
- 4.3.24
* Tue Nov 24 2020 ancor@suse.com
- Partitioner: fixed a crash when 'Do not format' is selected for a
  device that used to be part of a Btrfs (bsc#1179100).
- 4.3.23
* Fri Nov 20 2020 jreidinger@suse.com
- print properly help to avoid accidental opening of module by bash
  completion (bsc#1172340)
- 4.3.22
* Wed Nov 18 2020 shundhammer@suse.com
- Improved error handling for mounting /sys/firmware/efi/efivars
  (bsc#1174029):
  - Also check in /proc/filesystems if efivarfs is supported
  - Don't throw exception if a mount fails, just display a warning
- 4.3.21
* Wed Nov 11 2020 mvidner@suse.com
- Untranslated error message in 'Edit Btrfs subvolumes'/
  'Add subvolume' (bsc#1130822)
- Detect missing textdomain during unit testing.
- 4.3.20
* Thu Nov  5 2020 shundhammer@suse.com
- Disable "Device" menu items for NFS shares
  (related to jsc#PM-73, jsc#SLE-7742, jsc#SLE-15283)
- 4.3.19
* Wed Nov  4 2020 ancor@suse.com
- Proposal: adjusted the size and format of the EFI partition
  (bsc#1177358, bsc#1170625, bsc#1119318).
- 4.3.18
* Fri Oct 30 2020 ancor@suse.com
- Partitioner: revamped user interface (related to jsc#PM-73,
  jsc#SLE-7742, jsc#SLE-15283).
- 4.3.17
* Tue Oct 20 2020 shundhammer@suse.com
- Added $LIBSTORAGE_IGNORE_PROBE_ERRORS environment variable
  to ignore storage probing errors (bsc#1177332)
- 4.3.16
* Wed Aug 26 2020 igonzalezsosa@suse.com
- Unify profile element paths (bsc#1175680).
- 4.3.15
* Thu Aug  6 2020 ancor@suse.com
- AutoinstProposal now properly reports the proposal as failed when
  it fails to find the disks (bsc#1174469)
- 4.3.14
* Wed Aug  5 2020 ancor@suse.com
- Proposal: fixed detection of shadowed subvolumes for roles using
  separate LVM volume groups for each filesystem (bsc#1174475).
- 4.3.13
* Fri Jul 17 2020 dgonzalez@suse.com
- Partitioner: fix stripes size reported for thin LVs.
- Partitioner: do not show stripes size when its value is zero.
* Tue Jul  7 2020 dgonzalez@suse.com
- Partitioner: fix and improve the information shown for each
  type of LVM logical volumes.
- Partitioner: makes visible the relationship between an LVM
  snapshot and its original logical volume (related to
  bsc#1120410).
- Partitioner: warn the user before performing certain actions
  on an LVM snapshot.
- 4.3.12
* Fri Jul  3 2020 jlopez@suse.com
- AutoYaST: delegate to initial guided proposal when no partitions
  are defined in the profile (bsc#1173610).
- AutoYaST: fix enable_snapshots option.
- 4.3.11
* Tue Jun 30 2020 aschnell@suse.com
- install nvme-cli if NVMe devices are present (bsc#1172866)
- 4.3.10
* Fri Jun 26 2020 ancor@suse.com
- Ensure consistent removal of LVM snapshots when the origin LV
  is deleted (related to bsc#1120410).
- 4.3.9
* Wed Jun 10 2020 dgonzalez@suse.com
- Partitioner: does not warn the user when the BIOS Boot partition
  is missing in a XEN guest.
* Tue May 19 2020 schubi@suse.de
- AutoYaST: Cleanup/improve issue handling (bsc#1171335).
- 4.3.8
* Mon May 18 2020 aschnell@suse.com
- added translation for new resize blocking reason (bsc#1172164)
- 4.3.7
* Fri May 15 2020 snwint@suse.com
- ensure crypttab entries use correct mount_by variant (bsc#1165702)
- 4.3.6
* Tue May 12 2020 ags@localhost
- Partitioner: fixed a crash when libstorage-ng fails to report
  the block device of an LVM PV, which is a consequence of a wrong
  multipath setup (bsc#1170216).
- 4.3.5
* Mon May 11 2020 snwint@suse.com
- remove obsolete proposal_settings_editable (bsc#1171423)
- 4.3.4
* Wed Apr 29 2020 snwint@suse.com
- add x-initrd.attach option to crypttab if needed (bsc#1168465)
- 4.3.3
* Thu Apr 23 2020 snwint@suse.com
- update /etc/crypttab status properly (bsc#1118977)
- 4.3.2
* Wed Apr 22 2020 aschnell@suse.com
- disallow to edit LVM cache pools (related to bsc#1099744)
- 4.3.1
* Fri Apr 17 2020 dgonzalez@suse.com
- Fix the severity of some boot checks, making them warnings
  instead of errors.
* Fri Apr 17 2020 ancor@suse.com
- Proposal: in the initial attempt, consider only a reasonable
  number of disks (bsc#1154070).
- Proposal: speed up the initial attempt when "allocate_volume_mode"
  is set to "device" in the control file (part of jsc#SLE-7238).
- 4.3.0
* Wed Apr 15 2020 snwint@suse.com
- rework VFAT mount option handling (bsc#1161771)
* Mon Apr  6 2020 aschnell@suse.com
- allow to disable LUKS activation (bsc#1162545)
- 4.2.107
* Fri Apr  3 2020 ancor@suse.com
- Partitioner: fixed a crash when some devices are modified both
  before and after reprobing the hardware (bsc#1168325).
- 4.2.106
* Wed Apr  1 2020 ancor@suse.com
- Never add the _netdev option to fstab for the root mount point
  (bsc#1165937).
- 4.2.105
* Fri Mar 27 2020 ancor@suse.com
- Reverted the changes done to support the calculation of udev
  links from yast2-bootloader, since the changes in that module
  were also reverted. See previous entries for versions 4.2.90
  and 4.2.102.
- Related to bsc#1167779, bsc#1166096 and bsc#1151075.
- 4.2.104
* Thu Mar 26 2020 aschnell@suse.com
- Reanimate saving USED_FS_LIST (bsc#1161533).
- 4.2.103
* Wed Mar 25 2020 ancor@suse.com
- Extend and improve the API to get udev names for a block device
  (needed for bsc#1166096).
- 4.2.102
* Mon Mar 23 2020 dgonzalez@suse.com
- Prevents to put /boot in a bcache (bsc#1165903).
- 4.2.101
* Fri Mar 20 2020 igonzalezsosa@suse.com
- AutoYaST: show an error when no suitable components are found
  for Bcache, Btrfs multi-devices filesystems, and RAID devices
  (bsc#1167053).
- 4.2.100
* Thu Mar 19 2020 ancor@suse.com
- Partitioner: do not allow to clone a partition table to another
  device with a different block size (bsc#1166363)
- 4.2.99
* Wed Mar 18 2020 ancor@suse.com
- Restricted the scenarios in which software-defined RAIDs are
  eligible as target devices for the proposal. Do it only in systems
  with EFI (bsc#1166258).
- 4.2.98
* Fri Mar 13 2020 snwint@suse.com
- write nocow attribute correctly into YAML
- 4.2.97
* Thu Mar 12 2020 igonzalezsosa@suse.com
- AutoYaST: report the user when conflicting attributes are set
  in a partition section (i.e., mount, raid_name, lvm_group,
  btrfs_name, bcache_backing_for and bcache_caching_for)
  (bsc#1165907).
- 4.2.96
* Wed Mar 11 2020 ancor@suse.com
- Usability improvements when asking the user to install packages
  during the probing phase (related to bsc#1140040).
- More flexible API for PackageHandler and related classes
- More libstorage-ng "storage features" now recognized and handled
  if needed: UF_DASD, UF_BITLOCKER, UF_JFS, UF_F2FS, UF_EXFAT.
- Partitioner: better error reporting when the installation of
  needed packages fails.
- 4.2.95
* Mon Mar  9 2020 igonzalezsosa@suse.com
- AutoYaST: show an error when no suitable physical volumes are
  found for a given volume group (bsc#1162043).
- AutoYaST: do not append a suffix to LVM Volume Group names unless it
  is needed (bsc#1115749).
- 4.2.94
* Thu Mar  5 2020 jlopez@suse.com
- Fix unit tests for the progress dialog added in version 4.2.82
  (related to bsc#1135366).
- 4.2.93
* Tue Mar  3 2020 igonzalezsosa@suse.com
- AutoYaST: export the 'disklabel' attribute for software RAID
  devices.
- AutoYaST: include a 'partitions' section when exporting an
  unpartitioned software RAID which is not used as a filesystem
  (bsc#1159201).
- 4.2.92
* Fri Feb 28 2020 jlopez@suse.com
- Partitioner: allow to select APQNs when encrypting with pervasive
  encryption (jsc#SLE-7376).
- 4.2.91
* Thu Feb 20 2020 jlopez@suse.com
- Add API methods to get preferred mount by option and the
  associated device path.
- 4.2.90
* Thu Feb 20 2020 aschnell@suse.com
- allow to install packages needed for probing
- 4.2.89
* Wed Feb 19 2020 ancor@suse.com
- Proposal: fixed the infinite loop when trying to create a new
  partition out of the candidate devices (related to bsc#1161331
  and bsc#1161678).
- 4.2.88
* Tue Feb 18 2020 jlopez@suse.com
- Partitioner: do no show button for editing devices when the
  device cannot be used as block device (bsc#1163597).
- Revert changes from 4.2.85.
- 4.2.87
* Tue Feb 18 2020 ancor@suse.com
- Initial Guided Proposal: place the boot-related partitions in
  the device choosen for root, even if it's a software RAID
  (bsc#1161331, bsc#1161678).
- 4.2.86
* Tue Feb 18 2020 jlopez@suse.com
- Partitioner: do not allow to edit a device when the device cannot
  be used as block device (bsc#1163597).
- 4.2.85
* Wed Feb 12 2020 aschnell@suse.com
- added texts for RAID1C3 and RAID1C4 as required by
  gh#openSUSE/libstorage-ng#706 (related to jsc#SLE-3877)
- 4.2.84
* Wed Feb  5 2020 dgonzalez@suse.com
- Partitioner: usability improved by remembering the last active
  tab and selected device per page (bsc#1159883).
- 4.2.83
* Tue Feb  4 2020 jlopez@suse.com
- Partitioner: add a new progress dialog instead of simply closing
  when applying the changes in a running system (bsc#1135366).
- 4.2.82
* Fri Jan 31 2020 ancor@suse.com
- Partitioner: the button to delete all partitions does no longer
  fail for devices containing logical partitions (bsc#1162290).
- 4.2.81
* Wed Jan 29 2020 cwh@suse.com
- Added package requirement for UF_PLAIN_ENCRYPTION (bsc#1160773)
- 4.2.80
* Tue Jan 28 2020 aschnell@suse.com
- also mask swap units in mask-systemd-units (bsc#1152545)
- 4.2.79
* Fri Jan 24 2020 aschnell@suse.com
- reduce min height of dialogs (bsc#1161651)
- drop noatime, acl and xattr options in "Fstab Options" dialog
  (bsc#1135723)
- change mount by method to combobox in "Fstab Options" dialog
  (bsc#1135723)
- 4.2.78
* Thu Jan 23 2020 ancor@suse.com
- Avoided crash when libstorage-ng provides a non-UTF string as
  partition id (bsc#1161442).
- 4.2.77
* Tue Jan 21 2020 aschnell@suse.com
- added warning before resizing block devices which were probed
  empty (related to bsc#1159318)
- 4.2.76
* Tue Jan 21 2020 ancor@suse.com
- Guided Setup: enforced a consistent width for both password
  fields (bsc#1161202)
- 4.2.75
* Fri Jan 17 2020 dgonzalez@suse.com
- Partitioner: make it possible to directly work with devices
  from the overview/system page (related to fate#318196).
- 4.2.74
* Thu Jan 16 2020 jlopez@suse.com
- Improve integration with yast2-nfs-client.
- Related bugs: bsc#1006815, bsc#1151426.
- 4.2.73
* Wed Jan 15 2020 aschnell@suse.com
- treat partitions with BitLocker as Windows (related to
  bsc#1159318)
- 4.2.72
* Tue Jan 14 2020 aschnell@suse.com
- use udevadm in /usr/bin instead of /sbin (bsc#1160890)
- use absolute paths in mask-systemd-units
- 4.2.71
* Tue Jan 14 2020 aschnell@suse.com
- do not allow block sizes bigger than the system page size when
  creating xfs (bsc#1111668)
- check inode size depending on block size when creating xfs
- 4.2.70
* Thu Jan  9 2020 aschnell@suse.com
- disallow to mount BitLocker (related to bsc#1159318)
- 4.2.69
* Tue Jan  7 2020 jlopez@suse.com
- Use partition id names defined by libstorage-ng.
- 4.2.68
* Mon Dec 23 2019 aschnell@suse.com
- Improved sorting by device name and size in tables (bsc#1140018)
- 4.2.67
* Fri Dec 20 2019 ancor@suse.com
- Fixed an error when applying fallback_max_size_lvm in some corner
  cases (bsc#1075990).
- 4.2.66
* Thu Dec 19 2019 igonzalezsosa@suse.com
- AutoYaST: use the multipath device when the 'device' element
  points to one of its wires (bsc#1159081).
- 4.2.65
* Tue Dec 17 2019 jreidinger@suse.com
- Wrap long details message when error happens (bsc#1085468)
- 4.2.64
* Fri Dec 13 2019 ancor@suse.com
- Improved support for Raspberry Pi in the Guided Proposal: now it
  also works without preexisting firmware partition (jsc#SLE-7298)
- 4.2.63
* Wed Dec 11 2019 jlopez@suse.com
- Show device name when activating a LUKS device (related to
  bsc#1125774).
- 4.2.62
* Tue Dec 10 2019 jlopez@suse.com
- Generate encryption names according to the mount point of the
  encryption device (bsc#1125774).
- 4.2.61
* Wed Dec  4 2019 jlopez@suse.com
- Improve detection of Windows systems (related to bsc#1135341).
- 4.2.60
* Wed Nov 27 2019 cwh@suse.com
- Set passno to 2 for the ESP (bsc#1135523)
- 4.2.59
* Mon Nov 25 2019 jlopez@suse.com
- Detect root mount point probed as inactive (e.g., as result of a
  snapshot rollback without rebooting the system).
- Related to bsc#1124581.
- 4.2.58
* Thu Nov 21 2019 ancor@suse.com
- Fixed a wrong check that was preventing the installation of some
  needed packages (bsc#1151148).
- 4.2.57
* Thu Nov 14 2019 ancor@suse.com
- Propagate the noauto, nofail and _netdev options from fstab
  to crypttab (needed for jsc#SLE-7687).
- Add the _netdev option to fstab for mount points on top of a
  network-based device like iSCSI or FCoE (jsc#SLE-7687).
- 4.2.56
* Tue Nov 12 2019 igonzalezsosa@suse.com
- AutoYaST: allow to inject settings for the guided proposal
  (related to boo#1156539).
- 4.2.55
* Wed Nov  6 2019 igonzalezsosa@suse.com
- AutoYaST: do not repeat filesystem related information when
  cloning multidevice Btrfs filesystems (bsc#1148578).
- AutoYaST: do not export the enable_snapshots element for drives
  which do not contain the root filesystem.
- 4.2.54
* Wed Oct 30 2019 igonzalezsosa@suse.com
- AutoYaST: add support to set the encryption method (related to
  jsc#SLE-7376).
- 4.2.53
* Mon Oct 28 2019 aschnell@suse.com
- fix creation of secure key for new partitions (bsc#1154267)
- 4.2.52
* Wed Oct 23 2019 igonzalezsosa@suse.com
- AutoYaST: consider CT_DMMULTIPATH an alias of CT_DISK (related
  to bsc#1130988).
- 4.2.51
* Fri Oct 18 2019 igonzalezsosa@suse.com
- Fix translation of some encryption related widgets (bsc#1154364).
- 4.2.50
* Fri Oct 18 2019 igonzalezsosa@suse.com
- Avoid false warning about booting from LUKS2 in s390
  (related to jsc#SLE-7376).
* Wed Oct 16 2019 ancor@suse.com
- If a given device cannot be mounted by the method configured as
  default, try to find the most stable alternative instead of just
  using the device kernel name (bsc#1151075).
- Improved support for volatile encryption (related to
  jsc#SLE-7376).
- Partitioner: more accurate mount_by options in Fstab Options.
- 4.2.49
* Wed Oct 16 2019 igonzalezsosa@suse.com
- Set sector size to 4k for encrypted devices which underlying
  device is, at least, 4k too (jsc#SLE-7376).
- 4.2.48
* Fri Oct 11 2019 aschnell@suse.com
- Added translation for new enum value RB_PASSWORD_REQUIRED
  (bsc#1153871).
- 4.2.47
* Fri Oct  4 2019 ancor@suse.com
- AutoYaST: do not include the uuid field in the <partition>
  sections when cloning a system (bsc#1148477, bsc#1152535).
- 4.2.46
* Thu Oct  3 2019 ancor@suse.com
- AutoYaST: do not fail if the uuid is specified for a new
  filesystem (bsc#1148477, bsc#1152535).
- AutoYaST: partitions and logical volumes to be reused can now be
  found by uuid (bsc#1148477, bsc#1152535).
* Wed Oct  2 2019 dgonzalez@suse.com
- Partitioner: fix the type column value for Ext3/4 filesystems
  with an external journal (bsc#1145841).
- Do not crash when importing mount points from a multi-device
  filesystem.
- 4.2.45
* Wed Oct  2 2019 ancor@suse.com
- At the end of installation, copy the pervasive encryption keys
  to the zkey repository of the target system (jsc#SLE-7376).
- 4.2.44
* Tue Oct  1 2019 aschnell@suse.com
- implemented detection of pervasive encryption (for jsc#SLE-7376)
- 4.2.43
* Wed Sep 25 2019 jlopez@suse.com
- Partitioner: allow encrypting swap with protected and secure
  keys (part of jsc#SLE-7376).
- Partitioner: allow importing mount points from encrypted swap
  with protected and secure keys.
- 4.2.42
* Mon Sep 23 2019 dgonzalez@suse.com
- Partitioner: allows encrypting volumes using pervasive
  encryption (jsc#SLE-7376).
- 4.2.41
* Thu Sep 19 2019 dgonzalez@suse.com
- Partitioner: allow creating encrypted swap with random
  password (bsc#1088641).
- Partitioner: allow importing mount points from encrypted swap
  with random password.
- Storage: fix an encryption type inconsistency (bsc#1151079).
- 4.2.40
* Tue Sep 17 2019 snwint@suse.com
- add warning if /boot is on a LUKS2 encrypted partition
- 4.2.39
* Thu Sep  5 2019 ancor@suse.com
- Partitioner: better handling of existing encryptions, including
  the possibility of reusing them (related to jsc#SLE-7376).
* Wed Sep  4 2019 aschnell@suse.com
- added translation for new EncryptionType::PLAIN (bsc#1088641)
- 4.2.38
* Fri Aug 30 2019 snwint@suse.com
- bind-mount /run from inst-sys to target system during install (bsc#1136463)
- 4.2.37
* Wed Aug 28 2019 ancor@suse.com
- Partitioner: display encryption type (related to jsc#SLE-7376).
- 4.2.36
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.35
* Wed Aug 21 2019 snwint@suse.com
- log all ng proposal settings
- 4.2.34
* Sat Aug 10 2019 dgonzalez@suse.com
- Initial Guided Proposal: added support to make the proposal
  using all candidates devices, without trying all possible set
  of settings for each individual device first (related to
  jsc#SLE-7238).
- 4.2.33
* Thu Aug  8 2019 jlopez@suse.com
- AutoYaST: allow to create a Bcache without a caching device.
- AutoYaST: allow to create a Bcache over a LVM Logical Volume.
- bsc#1139783
- 4.2.32
* Wed Aug  7 2019 snwint@suse.com
- fix NilClass issue when calculating proposal on RAID (bsc#1139808)
- 4.2.31
* Mon Jul 29 2019 aschnell@suse.com
- Fixed exception when removing devices from btrfs (bsc#1142669)
- Sort selected devices in LVM VG and btrfs dialog by name
- 4.2.30
* Thu Jul 18 2019 ancor@suse.com
- Fixed some errors calculating the initial proposal, before the
  user has executed the Guided Setup (related to jsc#SLE-7238).
- 4.2.29
* Mon Jul 15 2019 shundhammer@suse.com
- Complain if user attempts to put /boot on a thin LVM or a BCache
  (bsc#1134130)
- 4.2.28
* Fri Jul 12 2019 dgonzalez@suse.com
- Guided Setup: added support for the new control file option
  "allocate_volume_mode". When set to "device", this option allows
  the user to specify a device per each volume (part of
  jsc#SLE-7238).
- 4.2.27
* Wed Jul 10 2019 jlopez@suse.com
- Add execute permissions to test files (bsc#1141006).
* Tue Jul  9 2019 jlopez@suse.com
- For Z Systems, the option to enlarge swap for suspend is always
  disabled by default, independently of its value in the control
  file (part of jsc#SLE-6926).
- 4.2.26
* Tue Jul  9 2019 shundhammer@suse.com
- AutoYaST: Fixed typo in filesystem type that caused a crash
  (bsc#1136272)
- 4.2.25
* Mon Jul  8 2019 jlopez@suse.com
- AutoYaST: do not delete related partitions if they are not
  specifically requested (related to bsc#1096760).
- 4.2.24
* Fri Jul  5 2019 jlopez@suse.com
- Proposal: add control file option to make configurable to resize
  and delete partitions (part of jsc#SLE-7238).
- 4.2.23
* Mon Jul  1 2019 jlopez@suse.com
- Partitioner: fix importing mount points from a multi-device
  Btrfs filesystem (bsc#1137997).
- 4.2.22
* Mon Jul  1 2019 jreidinger@suse.com
- adopt new rubocop to be able to use the latest ruby features
  (bsc#1139270)
- 4.2.21
* Tue Jun 18 2019 ancor@suse.com
- Proposal: initial support for several separate LVM volume groups
  (part of jsc#SLE-7238).
- 4.2.20
* Mon Jun 10 2019 jlopez@suse.com
- AutoYaST: add support for multi-device Btrfs filesystems.
- Part of jsc#SLE-3877.
- 4.2.19
* Fri May 31 2019 hellcp@mailbox.org
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
-4.2.18
* Fri May 17 2019 ancor@suse.com
- AutoYaST: do not ask for a reusable filesystem when it's not
  really needed (bsc#1134330).
- 4.2.17
* Thu May 16 2019 jlopez@suse.com
- Partitioner: allow to resize devices used by a multi-device
  Btrfs filesystem (part of jsc#SLE-3877).
- 4.2.16
* Mon May 13 2019 snwint@suse.com
- guided proposal frees space from existing multidevice btrfs properly
  (bsc#1096760); the same for raid using partitions
- 4.2.15
* Fri May 10 2019 ancor@suse.com
- Partitioner: button to delete Btrfs filesystems.
- Partitioner: prevent edition of block devices that are part of
  a multi-device Btrfs.
- Part of jsc#SLE-3877.
- 4.2.14
* Wed May  8 2019 jlopez@suse.com
- Partitioner: added option for creating Btrfs filesystems (single-
  and multidevice).
- Partitioner: added option for editing devices used by a Btrfs.
- Part of jsc#SLE-3877.
- 4.2.13
* Thu May  2 2019 dgonzalez@suse.com
- Partitioner: fix the Btrfs filesystem icon used in "Type" column.
- Partitioner: improve the value for the "Type" column when a volume
  group does not have name.
- Partitioner: fix the device name for a multidevice filesystem.
- Partitioner: do not show label nor mount point for devices used by
  a multidevice filesystem.
- Part of jsc#SLE-3877.
- 4.2.12
* Thu May  2 2019 ancor@suse.com
- Partitioner: fixes in the navigation tree (bsc#1133686).
- 4.2.11
* Tue Apr 30 2019 dgonzalez@suse.com
- Partitioner: unify the "Type" and "FS Type" columns.
- Partitioner: show multidevice filesystems in the system section.
- Part of jsd#SLE-3877.
- 4.2.10
* Tue Apr 30 2019 jlopez@suse.com
- Partitioner: added option for editing Btrfs filesystems.
- Part of jsd#SLE-3877.
- 4.2.9
* Wed Apr 24 2019 jlopez@suse.com
- Partitioner: BTRFS section was adapted to show both: multidevice
  and non-multidevice BTRFS filesystems.
- Partitioner: added page for each BTRFS filesystem.
- Part of jsd#SLE-3877.
- 4.2.8
* Mon Apr 22 2019 dgonzalez@suse.com
- Partitioner: by default, initialize the tree with sections
  expanded and devices collapsed.
- Partitioner: improves the user experience preserving, between
  every redraw, the tree items as the were: expanded or collapsed.
- Lightly related to fate#318196.
- 4.2.7
* Mon Apr 15 2019 ancor@suse.com
- Partitioner: fixed translation issues related to bcache
  (bsc#1126822).
- 4.2.6
* Wed Apr 10 2019 jlopez@suse.com
- AutoYaST: new format for importing/exporting NFS drives.
- Related to bsc#1130256.
- 4.2.5
* Wed Apr 10 2019 dgonzalez@suse.com
- Partitioner: when editing a block device, clean-up useless
  LVM PV metadata from it (bsc#1129663)
- 4.2.4
* Wed Apr  3 2019 jlopez@suse.com
- Fix NFS root detection when installing with AutoYaST
  (needed for bsc#1130256).
- 4.2.3
* Wed Apr  3 2019 dgonzalez@suse.com
- Fix initial proposal to make a clean copy of initial settings
  before switching to another candidate device (bsc#1130392).
- Related to bsc#1102026 and bsc#1090383.
- 4.2.2
* Tue Apr  2 2019 jlopez@suse.com
- Add support for installing over NFS with AutoYaST (bsc#1130256).
- 4.2.1
* Tue Apr  2 2019 ancor@suse.com
- Fixed unit tests to also work in ARM architecture (bsc#1130957).
* Wed Mar 27 2019 jlopez@suse.com
- Do not add mount options that are default (bsc#1122867).
- Short partition ids.
- Move windows system detection to ExistingFilesystem class.
- 4.2.0
* Tue Mar 26 2019 snwint@suse.com
- propose boot loader partitions only on system disk (bsc#1094927)
* Tue Mar 26 2019 jlopez@suse.com
- Improve unit tests: mocking architecture for Bcache is not needed
  anymore (fix regression tests for bsc#1129787).
- 4.1.77
* Mon Mar 25 2019 jlopez@suse.com
- Fix boot disk detection (bsc#1129787).
- 4.1.76
* Mon Mar 18 2019 igonzalezsosa@suse.com
- Fix bcache and AutoYaST related tests (related to fate#325346).
- 4.1.75
* Wed Mar 13 2019 jlopez@suse.com
- Show new icons for the options of the Configure menu button
  (related to bsc#1122174).
- 4.1.74
* Wed Mar 13 2019 schubi@suse.de
- Unifying name Bcache/bcache to bcache (fate#325346).
- 4.1.73
* Tue Mar 12 2019 igonzalezsosa@suse.com
- Add support for Bcache to AutoYaST (fate#325346).
- Fix reuse of RAID partitions for LVM volume groups and bcache
  devices.
- 4.1.72
* Mon Mar 11 2019 dgonzalez@suse.com
- Only exports the partition_type attribute when it belongs to a
  partition table with support for extended partitions
  (bsc#1115751).
* Wed Mar  6 2019 shundhammer@suse.com
- Prevent crash if resizing a newly formatted filesystem (bsc#1124146)
- 4.1.71
* Wed Mar  6 2019 lslezak@suse.cz
- Fixed "can't modify frozen String" crashes (related to
  bsc#1125006)
- Fixed missing translation (bsc#1127181)
- 4.1.70
* Mon Mar  4 2019 dgonzalez@suse.com
- Translates the filesystem roles properly (bsc#1127756).
- 4.1.69
* Thu Feb 28 2019 dgonzalez@suse.com
- Do not crash when using an old MD RAID schema and the
  partition_nr attribute is missing. Instead, do not allow to
  continue because a missing value issue (bsc#1126059).
- 4.1.68
* Wed Feb 27 2019 dgonzalez@suse.com
- Do not export the partition_type attribute when it belongs to a
  GPT partition table (bsc#1115751).
* Fri Feb 22 2019 jlopez@suse.com
- Partitioner: improve "Import Mount Points" feature.
  Now, a fstab entry cannot be imported when the filesystem type
  is not supported. Moreover, the "mount by" type is assigned
  according to the fstab entry and the label of the previous
  filesystem is preserved (bsc#1103391).
- 4.1.67
* Wed Feb 20 2019 shundhammer@suse.com
- Suggest /boot/efi as the mount point for EFI System Partitions
  (bsc#1088120)
- 4.1.66
* Wed Feb 20 2019 jreidinger@suse.com
- filesystem label is kept when using existing partitioning
  (bsc#1087229)
- 4.1.65
* Wed Feb 20 2019 jlopez@suse.com
- Partitioner: add new tab in Bcache section to show all caching
  set devices (part of fate#325346).
- 4.1.64
* Tue Feb 19 2019 ancor@suse.com
- Partitioner: new option "Provide Crypt Passwords" (bsc#1113515).
- 4.1.63
* Tue Feb 19 2019 jlopez@suse.com
- Partitioner: allow to edit bcache devices (part of fate#325346).
- 4.1.62
* Tue Feb 19 2019 shundhammer@suse.com
- Added help texts for guided setup (bsc#1121801)
- 4.1.61
* Mon Feb 18 2019 aschnell@suse.com
- AutoYaST: handle device_order for MD RAIDs during installation
  (bsc#1083542)
- 4.1.60
* Thu Feb 14 2019 shundhammer@suse.com
- Force mocking arch to x86_64 for unit tests that depend on bcache
  (part of jsc#SLE-4329)
- 4.1.59
* Thu Feb 14 2019 shundhammer@suse.com
- Limit bcache support to x86_64 arch (jsc#SLE-4329)
- 4.1.58
* Thu Feb 14 2019 ancor@suse.com
- Guided Setup: improved the disk selection user interface to
  properly support scenarios with many disks (bsc#1123688).
- 4.1.57
* Thu Feb 14 2019 aschnell@suse.com
- AutoYaST: save device_order for MD RAIDs (bsc#1083542)
- 4.1.56
* Fri Feb  8 2019 ancor@suse.com
- AutoYaST: fix broken support for retaining existing MD RAIDs in
  some scenarios (bsc#1120979,  bsc#1121720).
- 4.1.55
* Thu Feb  7 2019 jlopez@suse.com
- Partitioner: allow to create bcache devices without a caching
  set (part of fate#325346).
- 4.1.54
* Wed Feb  6 2019 ancor@suse.com
- Partitioner: when running standalone (in an installed system)
  abort gracefully if probing fails (bsc#1123837).
- 4.1.53
* Mon Feb  4 2019 jlopez@suse.com
- Remove setters for bcache attributes that cannot be permanent
  saved (writeback_percent and sequential_cutoff).
- Part of fate#325346.
- 4.1.52
* Mon Feb  4 2019 shundhammer@suse.com
- Limit ESP to min size on aarch64 (bsc#1119318)
- 4.1.51
* Thu Jan 31 2019 jlopez@suse.com
- Partitioner: properly show Flash-only Bcache devices.
- Part of fate#325346.
- 4.1.50
* Thu Jan 31 2019 aschnell@suse.com
- do not show hint for details button if button does not exist
  (bsc#1115807)
- 4.1.49
* Thu Jan 24 2019 ancor@suse.com
- Partitioning proposal: improved the calculation about how much
  each Windows partition must be resized (bsc#1121286).
- 4.1.48
* Wed Jan 23 2019 ancor@suse.com
- Make the storage proposal (i.e. the Guided Setup) easier to
  debug (bsc#1057436).
- 4.1.47
* Wed Jan 23 2019 aschnell@suse.com
- do not include nil in package list of used storage features
  for FC devices (bsc#1122781)
- 4.1.46
* Thu Jan 17 2019 ancor@suse.com
- Specific error pop-up for exceptions raised while calculating the
  storage actions (mitigation of bsc#1120070).
- 4.1.45
* Thu Jan 10 2019 jlopez@suse.com
- Allow to cancel Guided Setup (bsc#1121442).
- Link to storage client from installation summary (bsc#1099485).
- 4.1.44
* Tue Dec 18 2018 schubi@suse.de
- Do not touch eMMC boot partitions (mmcblk*boot*) (bsc#1119316)
- 4.1.43
* Tue Dec 18 2018 aschnell@suse.com
- do not use removed function IconPath anymore (bsc#1119699)
- 4.1.42
* Tue Dec 11 2018 jlopez@suse.com
- Hardening execution of system commands (part of bsc#1118291).
- 4.1.41
* Wed Dec  5 2018 hellcp@mailbox.org
- Ship only primary icons with module to avoid conflicts (boo#1118521)
- 4.1.40
* Tue Dec  4 2018 jlopez@suse.com
- Partitioner: does not allow to create BTRFS subvolumes with
  unsafe characters in its path (related to bsc#1059972).
- 4.1.39
* Fri Nov 30 2018 ancor@suse.com
- Support for Raspberry Pi in Guided Proposal: it suggests to keep
  the firmware partition and mount it as /boot/vc (fate#323484).
- 4.1.38
* Tue Nov 27 2018 noahadvs@gmail.com
- Provide icon with module (boo#1109310)
- 4.1.37
* Thu Nov 22 2018 jlopez@suse.com
- Partitioner: add support for UDF filesystem (fate#326877).
- 4.1.36
* Fri Nov 16 2018 ancor@suse.com
- The Guided Proposal tries to preserve partitions of type IRST
  (Intel Rapid Start Technology) when possible (bsc#1099187,
  fate#325885).
- Made the Guided Proposal algorithm more clear, so it's easier to
  debug (bsc#1057436).
- 4.1.35
* Fri Nov 16 2018 jlopez@suse.com
- Initial proposal tries all possible attempts over each candidate
  device before switching to another device.
- Related to bsc#1102026 and bsc#1090383.
- 4.1.34
* Fri Nov 16 2018 snwint@suse.com
- adjust boot requirements to handle RAID cases (fate#326573)
- 4.1.33
* Wed Nov 14 2018 schubi@suse.de
- SkipListValue.size_k returns the correct value (bsc#1115507).
- 4.1.32
* Thu Nov  8 2018 ancor@suse.com
- Internal code reorganization at Proposal::SpaceMaker
  (preparations for fate#325885 and fate#323484).
* Wed Nov  7 2018 jlopez@suse.com
- Crypttab entry allows to find a crypttab device by its UUID.
- Devicegraph#find_by_any_name is able to find a LUKS device by
  using its name at crypttab file.
- Related to bsc#1094963.
- 4.1.31
* Wed Nov  7 2018 dgonzalez@suse.com
- Improve the proposal to be able to work with existing MD RAIDs
  (fate#326573).
- 4.1.30
* Wed Oct 31 2018 shundhammer@suse.com
- Format the new multi-line compound actions correctly (bsc#1085134)
- 4.1.29
* Tue Oct 30 2018 snwint@suse.com
- do not include 'Partition' in partition type names
* Fri Oct 26 2018 snwint@suse.com
- allow creation of partitions starting before 1 MiB in expert
  partitioner
* Fri Oct 19 2018 igonzalezsosa@suse.com
- Fixes and improvements to AutoYaST partitioning:
  - Improve support to reuse a disk as a PV (bsc#1107298).
  - Resize and then create new devices (bsc#1112545).
  - Warn the user when trying to reuse a non-existent filesystem.
  - Fix support of old format to specify several software RAIDs
    (bsc#1112546).
  - Proper support for Xen virtual partitions (bsc#1105350).
  - Export enable_snapshots element properly (related to
    bsc#1073544).
  - Allow to format a whole disk and use it as a filesystem.
  - Add support for partitioned software RAIDs (fate#326573).
  - Allow to use a whole disk as a software RAID member (related
    to fate#326573).
- 4.1.28
* Fri Oct 19 2018 jreidinger@suse.com
- Add support for selecting cache mode during bcache creation
  (fate#325346)
- 4.1.27
* Thu Oct 18 2018 ancor@suse.com
- Improved UI responsiveness by caching the value of some internal
  methods (bsc#1112402):
  * StorageClassWrapper.downcasted_new
  * StorageEnv#active?
  * DiskDevice#types_for_is
- Improved compatibility with RSpec 3.8 by caching the objects
  used to wrap libstorage-ng enum values.
- 4.1.26
* Tue Oct 16 2018 jreidinger@suse.com
- Improve filtering of possible backing devices for bcache and
  limit deletion of bcache to only safe cases (fate#325346)
- 4.1.25
* Thu Oct 11 2018 ancor@suse.com
- Improved the warning messages about missing BIOS Boot partition,
  both in the Partitioner and in AutoYaST (bsc#1087275).
- Improved other AutoYaST warning messages related to the
  partitions needed for booting.
- 4.1.24
* Fri Oct  5 2018 jreidinger@suse.com
- Implement creating and deleting bcache devices (fate#325346)
- 4.1.23
* Tue Oct  2 2018 schubi@suse.de
- Fixed flickering testcase. Maybe produced by the fix of
  bsc#1108831.
- 4.1.22
* Tue Oct  2 2018 ancor@suse.com
- Partitioner: make it possible to directly format a disk (with
  no partitions).
- Partitioner: reorganized the user interface by grouping options
  to ensure all the new possibilities (like formatting a whole
  disk or creating partitions on an MD RAID) fit into text mode
  80x24 (part of fate#318196 and of fate#326573).
- 4.1.21
* Thu Sep 27 2018 schubi@suse.de
- AutoYaST proposal: Do not crash if existing boot partition
  cannot be used without formatting it. (bsc#1108831)
- 4.1.20
* Thu Sep 20 2018 jlopez@suse.com
- Partitioner: ask for unmounting when deleting a device.
- Partitioner: ask for unmounting when resizing a device.
- Part of fate#318196
- 4.1.19
* Thu Sep 20 2018 jlopez@suse.com
- AutoYaST: Allow to use whole disk as PV by indicating a partition
  with number 0 (bsc#1107298).
* Wed Sep 19 2018 lorenz@math.tu-berlin.de
- When trying to reuse a partition, AutoYaST will consider only
  those partitions from the right disk (bsc#1106774).
* Wed Sep 19 2018 dgonzalez@suse.com
- Do not crash when a partition content info cannot be
  detected (bsc#1101979).
- 4.1.18
* Wed Sep 19 2018 jreidinger@suse.com
- Add read-only support for Bcache (fate#325346)
- 4.1.17
* Wed Sep 19 2018 ancor@suse.com
- Partitioner: allow to manage partitions in software MD RAIDs
  (fate#318196, bsc#1094933 and bsc#1092417).
- 4.1.16
* Fri Sep  7 2018 ancor@suse.com
- Partitioner: do not offer partitions of other RAIDs as available
  devices to create MD RAID arrays (fate#318196).
- 4.1.15
* Wed Sep  5 2018 ancor@suse.com
- Partitioner: allow to add full disks and multipath devices (with
  no partition table) to MD RAID arrays (fate#318196).
- Partitioner: improved checks and workflow for "Create New
  Partition Table"
- More informative message when a device is in use.
- 4.1.14
* Tue Sep  4 2018 jreidinger@suse.com
- Add asterisk to mount points that is not active and also write it
  to description (FATE#318196)
- 4.1.13
* Thu Aug 30 2018 jlopez@suse.com
- Improved wording when moving partitions (bsc#1099599).
- 4.1.12
* Wed Aug 29 2018 jreidinger@suse.com
- Add support for Intel Rapid Start technology partitions
  (FATE#325885)
- 4.1.11
* Tue Aug 28 2018 ancor@suse.com
- Fixed a wrong unit test.
- 4.1.10
* Fri Aug 24 2018 mvidner@suse.com
- RAID attributes: include "Active: Yes/No" (bsc#1090010)
* Wed Aug 22 2018 knut.anderssen@suse.com
- Partitioner: Hide the "what to do" selector for windows
  partitions if there are no windows partitions (bsc#1055646)
- 4.1.9
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Wed Aug 22 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 shundhammer@suse.com
- Fixed crash in the Kubic proposal when insufficient disk space
  (bsc#1099762)
- 4.1.8
* Fri Aug 17 2018 ancor@suse.com
- AutoYaST: recognize Xen virtual partitions in the profile when
  importing and installing (bsc#1085134).
- 4.1.7
* Tue Aug 14 2018 igonzalezsosa@suse.com
- AutoYaST: set the 'mount by' option when reusing partitions
  (bsc#1104774).
- 4.1.6
* Tue Aug 14 2018 knut.anderssen@suse.com
- Partitioner: Permit going back when the partition dialog is
  skipped (bsc#1075443)
- 4.1.5
* Mon Aug 13 2018 ancor@suse.com
- Partitioner: fixed some strings that contained mistakes about
  format and/or internationalization.
* Fri Aug 10 2018 ancor@suse.com
- Fixed the warning about overwriting a manually edited partition
  layout. Now it works even after going back and forth in the
  installer steps (bsc#1055756).
- 4.1.4
* Thu Aug  9 2018 ancor@suse.com
- Partitioner: display Xen virtual partitions and allow to format
  and mount them (bsc#1085134).
* Tue Jul 31 2018 schubi@suse.de
- Warning if overwriting manually edited settings (bsc#1055756)
- 4.1.3
* Tue Jul 31 2018 igonzalezsosa@suse.com
- AutoYaST: export volume group name (lvm_group) when a MD RAID
  device is used as a physical volume (bsc#1103113).
- 4.1.2
* Thu Jul 26 2018 snwint@suse.com
- make bsc#1098594 regression test work on s390
- 4.1.1
* Wed Jul 25 2018 aschnell@suse.com
- use "Partition Table" instead of "Disk Label" in expert
  partitioner (bsc#1070570)
- 4.1.0
* Mon Jul 23 2018 snwint@suse.com
- document XEN guest setup for testing (bsc#1085134)
- 4.0.199
* Wed Jul 18 2018 ancor@suse.com
- Partitioner: when creating a partition, use only regions of
  the selected type: primary, logical or extended (bsc#1097634).
- 4.0.198
* Wed Jul 18 2018 ancor@suse.com
- AutoYaST: export BIOS RAID devices correctly (bsc#1098594).
- 4.0.197
* Mon Jul 16 2018 ancor@suse.com
- AutoYaST: do not crash when reusing partitions on non-disk
  devices like DASD or BIOS RAID (bsc#1098594).
- 4.0.196
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.195
* Fri Jun 22 2018 aschnell@suse.com
- mask systemd mount and swap units while expert partitioner is
  running (bsc#1073633)
- 4.0.194
* Tue Jun 19 2018 jlopez@suse.com
- Partitioner: add checkbox to format system volumes when importing
  mount points (bsc#1078359 and bsc#1094924).
- 4.0.193
* Fri Jun 15 2018 ancor@suse.com
- Partitioner: honor default subvolumes when importing the root
  mount point (related to bsc#1078359, bsc#1083851 and fate#318196)
- Partitioner: honor default snapshots configuration when importing
  the root mount point (bsc#966637)
* Thu Jun 14 2018 lslezak@suse.cz
- Fixed crash in the error callback when the text contained
  non-ASCII characters in the translated message (bsc#1096758)
- 4.0.192
* Wed Jun 13 2018 snwint@suse.com
- allow for numbers > 32 bit in region dialog (bsc#1065258)
- 4.0.191
* Tue Jun 12 2018 igonzalezsosa@suse.com
- Fix 'Arbitrary Option Value' translation (bsc#1081605).
- 4.0.190
* Tue Jun 12 2018 lslezak@suse.cz
- Use parallel_tests to speed up running the unit tests
  (bsc#1094875), active only in SLE15-SP1/Leap-15.1
* Tue Jun 12 2018 ancor@suse.com
- Better auto-generated names for encryption devices:
  * Based on the udev id of the encrypted devices instead of its
    kernel name (bsc#760213).
  * Adapted when partition numbers change, if doable (bsc#1094157).
  * Prevent collision with other DeviceMapper names (bsc#1094157).
- Do not write LUKS password of the proposal into YaST logs.
- Do not crash when registering a zero-sized device into the logs.
- 4.0.189
* Mon Jun 11 2018 igonzalezsosa@suse.com
- AutoYaST: fix handling of empty Btrfs subvolume prefixes
  (bsc#1096240).
- 4.0.188
* Thu Jun  7 2018 jlopez@suse.com
- Added method to update encryption names according to a crypttab
  file (needed for bsc#1094963).
- 4.0.187
* Tue Jun  5 2018 jlopez@suse.com
- Partitioner: fixed error when creating new BTRFS subvolumes in
  an installed system (bsc#1067510).
- 4.0.186
* Tue Jun  5 2018 shundhammer@suse.com
- Partitioner: Handle limitations for volume labels (bsc#1084867)
- 4.0.185
* Mon Jun  4 2018 jlopez@suse.com
- Partitioner: allow to move partitions (part of fate#318196).
- 4.0.184
* Thu May 17 2018 ancor@suse.com
- Added to the installer a detailed description about the origin of
  the partitioning layout, as discussed in bsc#1089274.
- 4.0.183
* Thu May 17 2018 jlopez@suse.com
- Allow to consider MD RAIDs as BIOS RAIDs by using the env
  variable LIBSTORAGE_MDPART (bsc#1092417).
* Thu May 17 2018 jlopez@suse.com
- Fixed tests to avoid to require files provided by
  yast-installation package (needed for bsc#1091047).
* Wed May 16 2018 jlopez@suse.com
- Fixed detection of candidate disks for installation
  (bsc#1091047).
- 4.0.182
* Wed May 16 2018 snwint@suse.com
- don't reuse prep partitions larger than 8 MiB (bsc#1090019)
- 4.0.181
* Wed May 16 2018 igonzalezsosa@suse.com
- Partitioner: fix several translation issues (bsc#1081837 and
  bsc#1081601).
* Mon May 14 2018 ancor@suse.com
- Expose the active flag of the MountPoint class (needed for the
  definitive fix for bsc#1064437 in modern distributions).
- 4.0.180
* Fri May 11 2018 igonzalezsosa@suse.com
- Partitioner: check whether required packages are installed
  before committing changes to disk (bsc#1089508).
- 4.0.179
* Fri May 11 2018 jlopez@suse.com
- Partitioner: fix buttons to abort and to go back
  (part of fate#318196 and related to bsc#1075443).
- Partitioner: fixed detection of reprobed system to avoid
  unnecessary proposal re-calculation.
* Fri May 11 2018 jlopez@suse.com
- Partitioner: allow to select only valid parity algorithms when
  creating a new MD RAID (bsc#1090182).
* Fri May 11 2018 ancor@suse.com
- Partitioner: "Configure..." button allowing to execute the
  YaST clients for iSCI, FCoE, DASD, zFCP and XPRAM (bsc#1090753).
* Wed May  9 2018 igonzalezsosa@suse.com
- AutoYaST: do not crash when size is set to 'auto' for a partition
  without a mount point (bsc#1092414).
- 4.0.178
* Tue May  8 2018 shundhammer@suse.com
- Add note to YAML files for devices not supported in YAML
  (part of fate#318196)
- 4.0.177
* Mon May  7 2018 shundhammer@suse.com
- Dump devicegraphs and actions in better strategic places
  (part of fate#318196)
- Make sure not to write LUKS passwords to YAML dump files
- 4.0.176
* Fri May  4 2018 aschnell@suse.com
- provide function to disable MD auto assembly (bsc#1090690)
- provide function to inhibit udisks from doing mounts
- use these two functions when running expert partitioner
- 4.0.175
* Fri May  4 2018 jlopez@suse.com
- Partitioner: added option to import mount points (part of
  fate#318196 and bsc#1083851).
- 4.0.174
* Fri May  4 2018 igonzalezsosa@suse.com
- AutoYaST: handle <subvolumes_prefix/> and <subvolumes> empty
  values properly (bsc#1076337, bsc#1090095 and bsc#1091669).
- 4.0.173
* Thu May  3 2018 ancor@suse.com
- Set fs_passno to 2 for ext2/3/4 filesystems assigned to non-root
  mount points (bsc#1078703).
- 4.0.172
* Thu May  3 2018 shundhammer@suse.com
- Don't require rspec/mocks (not present in inst-sys)
  (part of fate#318196)
- 4.0.171
* Wed May  2 2018 shundhammer@suse.com
- Dump devicegraph and actions to separate human readable files
  (part of fate#318196)
- 4.0.170
* Fri Apr 27 2018 ancor@suse.com
- Partitioner: fixed checks when the root filesystem is NFS
  (bsc#1090752).
- 4.0.169
* Fri Apr 27 2018 jreidinger@suse.com
- add method to check if system has any disk device (bsc#1090753)
- 4.0.168
* Fri Apr 27 2018 ancor@suse.com
- Set fs_passno to 1 for ext2/3/4 root filesystems (bsc#1078703).
- 4.0.167
* Fri Apr 27 2018 jreidinger@suse.com
- fix libstorage logging that do not expect printf expansion
  (bsc#1091062)
- 4.0.166
* Thu Apr 26 2018 ancor@suse.com
- Ensure the installer adds reused devices to /etc/crypttab and/or
  /etc/mdadm.conf if needed for booting (bsc#1071350).
- 4.0.165
* Wed Apr 25 2018 jlopez@suse.com
- Partitioner: fix bug after confirming changes in a running system
  (related to bsc#1086892).
- 4.0.164
* Tue Apr 24 2018 jlopez@suse.com
- Partitioner: do not validate setup just after rescanning
  (related to bsc#1086892).
- 4.0.163
* Mon Apr 23 2018 ancor@suse.com
- Partitioner: use the correct default value for 'Enable Snapshots'
  when the 'Operating System' role is chosen for a new device
  (bsc#1084491).
- 4.0.162
* Mon Apr 23 2018 jlopez@suse.com
- Make the package to be architecture dependant to correctly check
  the current architecture (bsc#1081198).
- 4.0.161
* Fri Apr 20 2018 igonzalezsosa@suse.com
- AutoYaST: properly handle empty proposals (bsc#1090390).
- 4.0.160
* Fri Apr 20 2018 ancor@suse.com
- Implemented the use_available LVM strategy for the proposal
  (part of fate#318196).
- Make use_available the new default LVM strategy, so the system
  behavior is closer to the old yast-storage.
- Speed improvements in the use_needed LVM strategy.
- 4.0.159
* Fri Apr 20 2018 jlopez@suse.com
- Partitioner: add missing warning and summary of changes when
  running in an installed system (part of fate#318196 and related
  to bsc#1086892).
- 4.0.158
* Thu Apr 19 2018 igonzalezsosa@suse.com
- Fix some translations issues in the Expert Partitioner
  (bsc#1081571).
* Wed Apr 18 2018 ancor@suse.com
- Updated libstorage-ng dependency to ensure slots on extended
  partitions are handled correctly and added regression unit test
  about it (bsc#1088483).
- Significant speed improvements in the proposal code.
* Tue Apr 17 2018 shundhammer@suse.com
- Added missing help texts in the partitioner (bsc#1079591)
- 4.0.157
* Fri Apr 13 2018 jlopez@suse.com
- Added support for settings 'expert_partitioner_warning' and
  'proposal_settings_editable' (bsc#1087486).
- Fix bug going back in Partitioner: only re-calculate proposal
  when the system was re-probed (bsc#1088960).
- 4.0.156
* Fri Apr 13 2018 igonzalezsosa@suse.com
- AutoYaST: support partition_type when set to "primary"
  (bsc#1081506).
- 4.0.155
* Fri Apr 13 2018 ancor@suse.com
- More informative message displayed when the proposal failed with
  some given settings, so it doesn't sound like a definitive error
  (related to bsc#1089274).
- 4.0.154
* Tue Apr 10 2018 jlopez@suse.com
- Partitioner: fix creation of default BTRFS subvolume
  (bsc#1087918 and bsc#1087763).
- 4.0.153
* Tue Apr 10 2018 ancor@suse.com
- Partitioner: make possible for the embedded yast2-nfs-client to
  access the vfstype field of fstab, so it can detect and correct
  legacy NFS entries (bsc#1088426).
- 4.0.152
* Tue Apr 10 2018 jlopez@suse.com
- Update dependency with libstorage-ng (ensure lock system).
- Part of fate#318196.
- 4.0.151
* Mon Apr  9 2018 ancor@suse.com
- Fixed the disable_order property of control.xml. Now it affects
  all the configurable aspects of the volume, as documented
  (related to bsc#1078495).
- 4.0.150
* Mon Apr  9 2018 jlopez@suse.com
- Add system lock to avoid several processes using the storage
  stack when a process is already using it with read-write access.
- Part of fate#318196.
- 4.0.149
* Mon Apr  9 2018 ancor@suse.com
- Force UTF-8 encoding for (most) strings coming from libstorage-ng
  (bsc#1088067).
- 4.0.148
* Thu Apr  5 2018 shundhammer@suse.com
- Better error handling if no storage proposal is possible
  (bsc#1064677)
- 4.0.147
* Tue Apr  3 2018 jlopez@suse.com
- Recover method #exists_in_probed? (bsc#1087818).
- 4.0.146
* Tue Apr  3 2018 igonzalezsosa@suse.com
- Partitioner: do not crash when a striped logical volume is
  selected (bsc#1087702).
* Tue Apr  3 2018 ancor@suse.com
- Fixed an error searching devices by name introduced by the recent
  sanitization related to bsc#1083672.
- 4.0.145
* Mon Apr  2 2018 jlopez@suse.com
- Partitioner: add check for minimum size when using snapshots
  (bsc#1085131).
- 4.0.144
* Mon Apr  2 2018 ancor@suse.com
- If a duplicate PV is found, show an specific error message with
  instructions (bsc#1082542).
- 4.0.143
* Mon Apr  2 2018 jlopez@suse.com
- Use correct probe mode in unit tests (fate#318196).
* Mon Mar 26 2018 ancor@suse.com
- Honor the LIBSTORAGE_MULTIPATH_AUTOSTART environment variable
  (part of fate#318196 and part of the fix for bsc#1082542).
- 4.0.142
* Mon Mar 26 2018 jlopez@suse.com
- Sanitize devicegraph after probing when there are LVM volume
  groups with missing physical volumes (bsc#1083672).
- 4.0.141
* Mon Mar 26 2018 shundhammer@suse.com
- Partitioner: Report detailed reasons why resizing is not possible
  (fate#318196)
- 4.0.140
* Mon Mar 26 2018 ancor@suse.com
- Partitioner: fixed an error that was causing filesystems to be
  deleted in some combination of actions (part of fate#318196).
* Fri Mar 23 2018 igonzalezsosa@suse.com
- AutoYaST: add support for LVM thin pools (bsc#1086596).
- AutoYaST: add support for stripes/stripesize elements.
- 4.0.139
* Mon Mar 19 2018 jlopez@suse.com
- Fix issues with zero-size devices (bsc#1083887).
- Proposal: do not use zero-size devices.
- Partitioner: completely hide zero-size devices.
- 4.0.138
* Fri Mar 16 2018 ancor@suse.com
- Added methods to deal with /etc/fstab specs (part of bsc#1071454)
- 4.0.137
* Fri Mar 16 2018 igonzalezsosa@suse.com
- AutoYaST: fixed space distribution on LVM volume groups when
  using percentages (bsc#1079369).
- AutoYaST: do not ignore free spaces smaller than 30MiB
  (bsc#1085627).
- 4.0.136
* Thu Mar 15 2018 jreidinger@suse.com
- Warn if user creates too big PReP partition which firmware can
  have problem to load (bsc#1081979)
- 4.0.135
* Thu Mar 15 2018 shundhammer@suse.com
- Partitioner: Check if resize is possible based on filesystem type
  (fate#318196)
- 4.0.134
* Thu Mar 15 2018 jlopez@suse.com
- Partitioner: do not allow to remove implicit partitions.
- Partitioner: allow to remove any disk device (not only disks).
- Part of fate#318196.
- 4.0.133
* Tue Mar 13 2018 shundhammer@suse.com
- Post a warning if reusing an existing system mount point without
  formatting during installation in the partitioner (bsc#1080073)
- 4.0.132
* Mon Mar 12 2018 igonzalezsosa@suse.com
- Add a new btrfs_read_only property to force the root filesystem
  to be read-only (bsc#1079000)
- Honor the subvolumes list for the root filesystem (bsc#1077866)
- 4.0.131
* Mon Mar 12 2018 jlopez@suse.com
- Partitioner: always allow to edit the partition id (bsc#1077868).
- 4.0.130
* Fri Mar  9 2018 ancor@suse.com
- Shadowed subvolumes that are ignored in the first proposal
  attempt are not longer omitted in subsequent ones (#bsc#1084213
  and bsc#1084261).
- 4.0.129
* Thu Mar  8 2018 jlopez@suse.com
- Make proposal to work with implicit partition tables (s390).
- Part of fate#318196.
- 4.0.128
* Wed Mar  7 2018 shundhammer@suse.com
- Make sure subvolumes use the same mount_by as their parent btrfs
  (bsc#1080408)
- 4.0.127
* Wed Mar  7 2018 ancor@suse.com
- Better control on whether a separate /boot/zipl is needed in
  S/390 systems, both in the Guided Setup and the Partitioner.
- Do not longer report FBA DASDs to be unsupported devices for
  booting (they are indeed supported).
- Part of bsc#1070265.
- 4.0.126
* Wed Mar  7 2018 snwint@suse.com
- fix translations in blk_device_resize.rb (bsc#1081598)
- 4.0.125
* Mon Mar  5 2018 jlopez@suse.com
- Guided proposal uses preferred partition table type when
  possible (e.g., all partitions are deleted).
- Part of fate#318196.
- 4.0.124
* Mon Mar  5 2018 jreidinger@suse.com
- Add specialized warning when /boot/efi is on software RAID
  (bsc#1081578)
- 4.0.123
* Mon Mar  5 2018 igonzalezsosa@suse.com
- AutoYaST: do not stop installation when there is not enough
  space for automatically added boot devices (bsc#1082999).
* Fri Mar  2 2018 igonzalezsosa@suse.com
- AutoYaST: support to export LVM volume group and MD RAIDs
  (bsc#1081331).
* Fri Mar  2 2018 ancor@suse.com
- New PReP partitions proposed by the Guided Setup are now always
  primary (bsc#1082468).
- 4.0.122
* Fri Mar  2 2018 snwint@suse.com
- ensure proper hierarchy when creating btrfs subvolumes (bsc#1078732)
- 4.0.121
* Thu Mar  1 2018 shundhammer@suse.com
- Use default swap priority, not 42 (bsc#1066077)
- 4.0.120
* Thu Mar  1 2018 jreidinger@suse.com
- Do not crash for separate /boot which does not exists yet
  (bsc#1078774
- 4.0.119
* Thu Mar  1 2018 jlopez@suse.com
- Partitioner: allow to clone a disk (part of fate#318196).
- 4.0.118
* Wed Feb 28 2018 ancor@suse.com
- More reliable parsing for the hwinfo output (bsc#1082536).
- Better documentation and tests for activate callbacks.
- 4.0.117
* Wed Feb 28 2018 aschnell@suse.com
- adapted to new activate callbacks in libstorage-ng (see
  bsc#1082542)
- 4.0.116
* Tue Feb 27 2018 igonzalezsosa@suse.com
- Keep encryption when adding a device to a LVM volume group
  (bsc#1077750).
- 4.0.115
* Tue Feb 27 2018 ancor@suse.com
- Improved handling of libstorage-ng errors (bsc#1070459,
  bsc#1079228, bsc#1079817, bsc#1063059, bsc#1080554, bsc#1076776,
  bsc#1070459 and some others).
- 4.0.114
* Mon Feb 26 2018 shundhammer@suse.com
- Use format(), not Ruby variable expansion for translated messages
  (bsc#1081454)
- 4.0.113
* Mon Feb 26 2018 ancor@suse.com
- Partitioner: ensure a valid password is provided when encrypting
  a device (bsc#1065079).
- Increase to 8 characters the minimum size to consider an
  encryption password to be valid (same limit than yast2-storage).
- 4.0.112
* Fri Feb 23 2018 jreidinger@suse.com
- Do not allow to encrypt too small partition (bsc#1065071)
- Check size for separate /boot
- 4.0.111
* Fri Feb 23 2018 jlopez@suse.com
- Partitioner: prevent to modify devices used in LVM or MD RAID
  (bsc#1079827).
- 4.0.110
* Fri Feb 23 2018 ancor@suse.com
- Better handling of errors during hardware probing (bsc#1070459,
  bsc#1079228, bsc#1079817, bsc#1063059, bsc#1080554, bsc#1076776,
  bsc#1070459 and some others).
- 4.0.109
* Fri Feb 23 2018 jlopez@suse.com
- Avoid to write files in tests (SCR.Write) (fate#323457).
* Thu Feb 22 2018 aschnell@suse.com
- adapted to callback improvements in libstorage-ng (bsc#1070459
  and many others)
- 4.0.108
* Thu Feb 22 2018 shundhammer@suse.com
- Added missing textdomain calls (bsc#1081454)
- 4.0.107
* Thu Feb 22 2018 igonzalezsosa@suse.com
- AutoYaST: fix support to create multiple volume groups
  (bsc#1081633).
- 4.0.106
* Thu Feb 22 2018 shundhammer@suse.com
- Added missing ptable type conversion (fate#323457)
- 4.0.105
* Thu Feb 22 2018 shundhammer@suse.com
- Changed default partition table from MSDOS to GPT (fate#323457)
- 4.0.104
* Thu Feb 22 2018 snwint@suse.com
- ensure partition name changes during the proposal process are taken
  properly into account (bsc#1078691)
- 4.0.103
* Wed Feb 21 2018 jlopez@suse.com
- Use sysconfig storage file to read the default value for mount_by
  (bsc#1081198).
- Partitioner: allow to configure default value for mount_by.
- 4.0.102
* Wed Feb 21 2018 ancor@suse.com
- Do not take into account unformatted DASDs as a possible target
  for installation (bsc#1071798).
- Partitioner: do not show unformatted DASDs, since they cannot
  be partitioned or used in any other way.
* Wed Feb 21 2018 igonzalezsosa@suse.com
- AutoYaST: guess which filesystem type should be used for a given
  partition/logical volume when it is not specified in the profile
  (bsc#1075203).
* Tue Feb 20 2018 shundhammer@suse.com
- Special handling for mount options for / and /boot/*
  in the partitioner (bsc#1080731)
- 4.0.101
* Tue Feb 20 2018 ancor@suse.com
- Partitioner: bring back traditional list of mount points for both
  installation and installed system (bsc#1076167 and bsc#1081200).
- Partitioner: bring back traditional behavior of the "Operating
  System" and "Data" roles during installation (bsc#1078975 and
  bsc#1073854).
- 4.0.100
* Mon Feb 19 2018 shundhammer@suse.com
- Special handling for mount options for / and /boot/*
  (bsc#1080731, bsc#1061867, bsc#1077859)
- 4.0.99
* Mon Feb 19 2018 jreidinger@suse.com
- Ensure that there is always selected item in table, if it is not
  empty (bsc#1076318)
- 4.0.98
* Thu Feb 15 2018 ancor@suse.com
- Adjusted the suggested and minimum sizes of all the booting
  partitions, both in the storage proposal and in the Partitioner
  validations (bsc#1076851 and fate#318196).
- 4.0.97
* Thu Feb 15 2018 igonzalezsosa@suse.com
- Fix hwinfo parsing to support more than one device_file property
  (bsc#1080999)
- 4.0.96
* Thu Feb 15 2018 jreidinger@suse.com
- Split detection of problematic boot scenarios into errors and
  warnings. With warnings user can continue, but not with errors.
  (bsc#1074475)
- 4.0.95
* Wed Feb 14 2018 jlopez@suse.com
- PowerPC: do not require /boot partition for non-PowerNV
  (bsc#1070139).
- Partitioner: do not enforce partition id for /boot/efi
  (bsc#1078707).
- 4.0.94
* Mon Feb 12 2018 snwint@suse.com
- add format options dialog (bsc#1077868)
- 4.0.93
* Mon Feb 12 2018 ancor@suse.com
- More reasonable location in the disk for the partitions proposed
  to make the system bootable (bsc#1073680 and bsc#1076851).
* Fri Feb  9 2018 jlopez@suse.com
- Partitioner: fix issues using transactions (bsc#1079880 and
  bsc#1079573).
- 4.0.92
* Fri Feb  9 2018 ancor@suse.com
- Enable multipathd in the target system at the end of installation
  if there are multipath devices (bsc#1076183).
- Updated required version of libstorage-ng-ruby (bsc#1079541).
- 4.0.91
* Thu Feb  8 2018 jlopez@suse.com
- Add class MountPoint (needed for bsc#1076305 and bsc#1066763).
- 4.0.90
* Thu Feb  8 2018 ancor@suse.com
- Partitioner: fixed creation of partition tables (bsc#1078721).
- 4.0.89
* Thu Feb  8 2018 ancor@suse.com
- Partitioner: fixed 'Installation Summary' section (part of
  fate#318196).
- 4.0.88
* Thu Feb  8 2018 igonzalezsosa@suse.com
- AutoYaST: support additional names in the drive/device element
  (bsc#1077277).
- 4.0.87
* Wed Feb  7 2018 shundhammer@suse.com
- Disabled empty pages in partitioner for the time being
  (bsc#1078849)
- 4.0.86
* Wed Feb  7 2018 igonzalezsosa@suse.com
- AutoYaST: support reuse of already existing partitions as LVM
  physical volumes or MD RAIDs (bsc#1077277).
- 4.0.85
* Wed Feb  7 2018 ancor@suse.com
- Partitioner: fixed 'Device Graph' section (part of fate#318196).
- 4.0.84
* Mon Feb  5 2018 ancor@suse.com
- Added a new 'disk' client, alias for 'partitioner' (bsc#1078900).
- 4.0.83
* Wed Jan 31 2018 shundhammer@suse.com
- Handle arbitrary mount options for /etc/fstab properly
  (bsc#1066076)
- 4.0.82
* Wed Jan 31 2018 jlopez@suse.com
- Partitioner: list all LVM thin volumes to delete when an LVM thin
  pool is going to be deleted.
- Partitioner: show warning when an LVM thin pool is overcommitted
  after resizing.
- Part of fate#318196.
- 4.0.81
* Wed Jan 31 2018 igonzalezsosa@suse.com
- AutoYaST: try to shrink new partitions/logical volumes
  proportionally when there is not enough space (bsc#1078418).
- 4.0.80
* Wed Jan 31 2018 ancor@suse.com
- Partitioner: initial support for NFS (part of fate#318196)
- Partitioner: removed useless tmpfs option
- 4.0.79
* Tue Jan 30 2018 jlopez@suse.com
- Partitioner: allow to create LVM thin pools and volumes.
- Fix transactions of devicegraphs.
- Part of fate#318196.
- 4.0.78
* Tue Jan 30 2018 jlopez@suse.com
- Partitioner: improve error message when trying to remove an used
  physical volume.
* Thu Jan 25 2018 shundhammer@suse.com
- Add default mount options for /etc/fstab for ext2/3/4 and vfat
  (bsc#1066076)
- 4.0.77
* Wed Jan 24 2018 igonzalezsosa@suse.com
- Properly detect snapshots subvolumes (bsc#1076321 and
  bsc#1076335).
- 4.0.76
* Tue Jan 23 2018 jlopez@suse.com
- Partitioner: allow to resize LVM volume groups.
- Part of fate#318196.
- 4.0.75
* Tue Jan 23 2018 ancor@suse.com
- Partitioner: consider all sizes entered by the user as base of 2
  despite the units not being consistent with the International
  System. Thus, 1KB (which in the IS actually means 1000 bytes)
  becomes equivalent to 1KiB (which is 1024 bytes).
* Tue Jan 23 2018 snwint@suse.com
- fix proposal dialog error when there are no disks (bsc#1057430)
* Mon Jan 22 2018 jlopez@suse.com
- Avoid partitioning checks error when using old settings format.
- Needed for bsc#1059160, bsc#1055747 and bsc#1063957.
* Mon Jan 22 2018 ancor@suse.com
- Partitioner: button to resize LVM logical volumes now works as
  expected (part of fate#31896).
- 4.0.74
* Mon Jan 22 2018 igonzalezsosa@suse.com
- Consider all free spaces when deciding which partitions
  distribution is better (bsc#1077051).
* Fri Jan 19 2018 jlopez@suse.com
- Fix TODOs labels in partitioner (bsc#1058652).
- 4.0.73
* Fri Jan 19 2018 jreidinger@suse.com
- Fix subtracting arrays of devices (fixes multipath wires
  detection for bsc#1076766)
- 4.0.72
* Fri Jan 19 2018 ancor@suse.com
- Partitioner: when creating partitions they are now aligned to
  hardware requirements (indispensable for DASD) and when possible
  also for optimal performance (bsc#1069860 and bsc#1072011).
- Partitioner: adjusted alignment logic during resizing to match
  the new logic used during creation.
- Partitioner: skip validation of disabled widgets in the dialog
  to select the size of a new partition.
- Partitioner: fixed a crash and one inconsistency in the dialog
  to resize an existing partition.
- 4.0.71
* Fri Jan 19 2018 ancor@suse.com
- Correctly open the expert partitioner when called from the
  Kubic/CaaSP summary screen (bsc#1076732)
- 4.0.70
* Mon Jan 15 2018 jlopez@suse.com
- Added sanity checks for partitioning setup.
- Partitioner: setup issues are shown to the user before continue.
  Mandatory product volumes are required according to control file.
- Part of fate#31896 and fix for bsc#1059160, bsc#1055747 and
  bsc#1063957.
- 4.0.69
* Mon Jan 15 2018 ancor@suse.com
- Some code reorganization regarding alignment and resizing.
- Added to several places in the API the possibilty of using other
  alignment types, in addition to the optimal one.
- Added a (temporary) workaround to a possible bug in libstorage-ng
  regarding alignment.
* Tue Jan  9 2018 lslezak@suse.cz
- Added Mountable#persistent? (needed for bsc#1073696)
- 4.0.68
* Mon Jan  8 2018 ancor@suse.com
- Added Devicegraph#find_by_any_name (needed for bsc#1073254)
- 4.0.67
* Mon Jan  8 2018 ancor@suse.com
- Do not try to reuse UUID and label from unformatted swap
  partitions (bsc#1071515).
- 4.0.66
* Mon Jan  8 2018 igonzalezsosa@suse.com
- Force the subvolume name to be relative (related to bsc#1073548)
- 4.0.65
* Mon Jan  8 2018 ancor@suse.com
- Fixed error when calculating the proposal on top of a BIOS RAID
  (bsc#1067349)
* Fri Dec 22 2017 igonzalezsosa@suse.com
- AutoYaST: export the enable_snapshots element (bsc#1073544)
* Fri Dec 22 2017 snwint@suse.com
- rewrite SpaceMaker::resize_and_delete! to be more human-readable
- 4.0.64
* Fri Dec 22 2017 snwint@suse.com
- fix unnecessary Windows partition deletion (bsc #1066386)
- 4.0.63
* Fri Dec 22 2017 snwint@suse.com
- fix logic in GuidedProposal::calculate_proposal (bsc#1058027)
- 4.0.62
* Fri Dec 22 2017 igonzalezsosa@suse.com
- Do not crash when showing an unhandled partition id
  (bsc#1068087)
* Wed Dec 20 2017 ancor@suse.com
- Partitioner: support for deleting an LVM volume group.
- Correct handling of orphan physical volume devices.
- Fix for bsc#106956 and part of fate#31896.
- 4.0.61
* Wed Dec 20 2017 aschnell@suse.com
- added obsoletes (bsc#1073645)
- 4.0.60
* Tue Dec 19 2017 ancor@suse.com
- Added BlkDevice.find_by_any_name (needed for bsc#1073254)
- 4.0.59
* Tue Dec 19 2017 jreidinger@suse.com
- Add DeviceGraph#find_by_name call (needed for bsc#1072908)
- 4.0.58
* Mon Dec 18 2017 igonzalezsosa@suse.com
- AutoYaST: Improve disklabel element handling (bsc#1073307).
- 4.0.57
* Thu Dec 14 2017 ancor@suse.com
- Fixed a recently added unit test to not rely on libstorage-ng
  sorting. Related to bsc#1049901 and part of fate#31896.
- 4.0.56
* Mon Dec 11 2017 jlopez@suse.com
- Partitioner: add buttons to Hard Disks section for creating new
  partitions and editing devices.
- Part of fate#318196.
- 4.0.55
* Mon Dec 11 2017 ancor@suse.com
- Improved how the proposal handles disks that are in use but don't
  have a partition table (directly formatted disks, disks that are
  direct members of an LVM or RAID, etc.).
  Preliminary fix for bsc#1071949 and bsc#1067670.
- 4.0.54
* Mon Dec 11 2017 jlopez@suse.com
- Improve detection of efi and swap partitions.
- bsc#1071775 and bsc#1065234
- 4.0.53
* Fri Dec  8 2017 locilka@suse.com
- Fixed dependencies (yast2 >= 4.0.24) (fate#318196)
- 4.0.52
* Tue Dec  5 2017 igonzalezsosa@suse.com
- AutoYaST: assign the correct partition_id to /boot/efi
  (bsc#1071167)
- 4.0.51
* Tue Dec  5 2017 ancor@suse.com
- Don't trust any longer the order of any collection coming from
  libstorage-ng (related to bsc#1049901 and part of fate#31896).
- 4.0.50
* Mon Dec  4 2017 jlopez@suse.com
- Partitoner: added support for resizing partitions (bsc#1057586).
- Part of fate#318196.
- 4.0.49
* Mon Dec  4 2017 igonzalezsosa@suse.com
- AutoYaST does not ignore the 'enable_snapshots' setting even
  if the list of partitions is missing (bsc#1070790).
- 4.0.48
* Fri Dec  1 2017 ancor@suse.com
- Rely on the new improved mechanism of libstorage-ng to sort
  devices by name. Preparation for bsc#1049901 and part of
  fate#31896.
- 4.0.47
* Fri Dec  1 2017 igonzalezsosa@suse.com
- Fix boot partition detection (bsc#1070621).
- 4.0.46
* Fri Dec  1 2017 igonzalezsosa@suse.com
- AutoYaST honors 'use' and 'initialize' elements even if the
  list of partitions is missing (related to bsc#1065061).
- 4.0.45
* Thu Nov 30 2017 ancor@suse.com
- Partitioner: added buttons to sort the devices being added to
  an MD RAID (part of fate#318196).
- 4.0.44
* Thu Nov 30 2017 igonzalezsosa@suse.com
- Do not ignore start_multipath setting (bsc#1070343).
- 4.0.43
* Wed Nov 29 2017 snwint@suse.com
- adjust list of partition ids in expert partitioner (bsc#1060993,
  fate#314888)
- 4.0.42
* Tue Nov 28 2017 igonzalezsosa@suse.com
- AutoYaST: honor size=max for logical volumes (bsc#1070131).
- 4.0.41
* Mon Nov 27 2017 jlopez@suse.com
- Allow to work with BIOS RAIDs as regular disks (bsc#1067349).
- Allow to create partition table over directly formatted devices.
- 4.0.40
* Mon Nov 27 2017 snwint@suse.com
- make PartitionTables::partition_id_supported? available
- 4.0.39
* Fri Nov 24 2017 ancor@suse.com
- Fixed a problem when confirming the very same partitioning schema
  several times (bug#1069671).
- 4.0.38
* Fri Nov 24 2017 igonzalezsosa@suse.com
- AutoYaST: safer handling of partition ids (bsc#1067207).
- 4.0.37
* Thu Nov 23 2017 igonzalezsosa@suse.com
- AutoYaST: add support to resize partitions and logical volumes
  (bsc#1069505).
- AutoYaST: fix detection of root partition when using LVM
  (bsc#1069647).
- 4.0.36
* Thu Nov 23 2017 ancor@suse.com
- Ensure that disks considered for (auto)installation are always
  sorted in a stable and consistent way based on its device name.
  Preparation for bsc#1049901 and part of fate#31896.
- 4.0.35
* Wed Nov 22 2017 jlopez@suse.com
- Partitioner: added support for resizing MD RAIDs.
- Part of fate#318196.
- 4.0.34
* Wed Nov 22 2017 shundhammer@suse.com
- No RAID chunk size below 64 kiB for most types of RAID
  (bsc#1065381)
- 4.0.33
* Mon Nov 20 2017 shundhammer@suse.com
- Added "Create New Partition Table" in partitioner
- Part of fate#318196.
- 4.0.32
* Thu Nov 16 2017 jlopez@suse.com
- Improve logging: add wrapper param for guard method and dump xml
  representation of the devicegraph to the logs.
- Part of fate#318196.
- 4.0.31
* Wed Nov 15 2017 ancor@suse.com
- When proposing a partitions layout for installation, prefer
  getting big installations and arranging the partitions by their
  weights over creating adjacent partitions. Part of fate#318196.
- 4.0.30
* Tue Nov 14 2017 jlopez@suse.com
- Partitioner: added support for creating volume groups.
- Part of fate#318196.
- 4.0.29
* Wed Nov  8 2017 snwint@suse.com
- safer handling of partition ids (bsc#1060993
- 4.0.28
* Wed Nov  8 2017 igonzalezsosa@suse.com
- AutoYaST: filter out old '@' entries when importing the list of
  subvolumes (bsc#1061253)
- 4.0.27
* Wed Nov  8 2017 ancor@suse.com
- Added support in the UI of the guided setup for the new format
  of <volumes> in the control file.
- Part of fate#318196.
- 4.0.26
* Wed Nov  8 2017 igonzalezsosa@suse.com
- AutoYaST: fix space distribution when partition table does not
  exist (bsc#1065061)
- AutoYaST: set partition tables type according to the profile
- 4.0.25
* Tue Nov  7 2017 jlopez@suse.com
- Fix name of planned logical volumes.
- Take into account real RAM size to plan volumes.
- Add scenario tests using new partitioning settings.
- Part of fate#318196.
- 4.0.24
* Tue Nov  7 2017 igonzalezsosa@suse.com
- AutoYaST: adjust the list of allowed keys in skip lists
  (bsc#1065668)
- 4.0.23
* Tue Nov  7 2017 igonzalezsosa@suse.com
- AutoYaST: add support for udev links in the <device/> element
  (bsc#1066320)
- 4.0.22
* Fri Nov  3 2017 igonzalezsosa@suse.com
- AutoYaST: do not remove partitions that are supposed to be reused
  (bsc#1066398).
- 4.0.21
* Fri Nov  3 2017 jlopez@suse.com
- Partitioner: support for deleting md raids.
- Part of fate#318196.
- 4.0.20
* Fri Nov  3 2017 aschnell@suse.com
- do not query end of region if region is empty (bsc#1066290)
- 4.0.19
* Thu Nov  2 2017 igonzalezsosa@suse.com
- AutoYaST: query hardware information on skip lists (bsc#1065668).
- AutoYaST: support multi-valued keys on skip lists.
- AutoYaST: do not crash when no suitable disk for installation
  is found.
- 4.0.18
* Wed Nov  1 2017 jlopez@suse.com
- Partitioner: support for deleting logical volumes.
- Part of fate#318196.
- 4.0.17
* Wed Nov  1 2017 igonzalezsosa@suse.com
- AutoYaST: do not crash when an unknown key is used in a
  skip list (bsc#1065670).
- 4.0.16
* Tue Oct 31 2017 igonzalezsosa@suse.com
- AutoYaST: fix reuse of partitions (bsc#1060637).
- AutoYaST: improve error handling when trying to reuse a partition
  fails.
- AutoYaST: when a problem is detected while creating a proposal,
  register in which section it was found.
- AutoYaST: register an issue when a proposal does not contain
  a root (/) partition.
- 4.0.15
* Mon Oct 30 2017 ancor@suse.com
- Added an option in the installer to run the expert partitioner
  with the current storage layout as starting point.
- Possible fix for bsc#1055644 and part of fate#318196.
- 4.0.14
* Fri Oct 27 2017 jsrain@suse.cz
- Limit maximal proposed size of EFI partition (bsc#1062775)
- 4.0.13
* Thu Oct 26 2017 ancor@suse.com
- Partitioner: small adjustments in the verifications performed
  before running some wizards.
* Wed Oct 25 2017 jlopez@suse.com
- Partitioner: allow to work with multipath devices.
- bsc#1058373 and bsc#1028853.
- Part of fate#318196.
- 4.0.12
* Wed Oct 25 2017 igonzalezsosa@suse.com
- Add support to clone subvolumes when using AutoYaST (bsc#1064875)
- 4.0.11
* Wed Oct 25 2017 snwint@suse.de
- adjust control.xml documentation
- 4.0.10
* Mon Oct 23 2017 jlopez@suse.com
- Partitioner: show only option to create vg when there are no vgs.
- Part of fate#318196.
- 4.0.9
* Mon Oct 23 2017 snwint@suse.de
- have volumes in control.xml proposed by default (fate#318196)
- 4.0.8
* Fri Oct 20 2017 jlopez@suse.com
- Partitioner: support for creating logical volumes.
- Part of fate#318196.
- 4.0.7
* Thu Oct 19 2017 igonzalezsosa@suse.com
- AutoYaST: add basic support for error handling
- AutoYaST: handle 'size: auto' correctly
- 4.0.6
* Thu Oct 19 2017 jsrain@suse.cz
- During installation, mount efivarfs in /mnt/sys/firmware/efivars
  if present in inst-sys (bsc#1063063)
- 4.0.5
* Tue Oct 17 2017 shundhammer@suse.de
- Terminate extra space distribution loop if nothing could be
  distributed anymore (bsc#1063392)
- 4.0.4
* Tue Oct 17 2017 snwint@suse.com
- finalize control.xml description (fate#318196)
- 4.0.3
* Mon Oct 16 2017 jlopez@suse.com
- Add strategies to try an initial valid proposal, even changing
  settings when necessary.
- Part of fate#318196.
- 4.0.2
* Tue Oct 10 2017 jlopez@suse.com
- Adapt proposal to work with new format of proposal settings.
- Part of fate#318196.
- 4.0.1
* Mon Oct  9 2017 igonzalezsosa@suse.com
- AutoYaST: proper handling of the 'use' element allowing to
  delete a set of partitions (bsc#1061042)
- AutoYaST: support for mkfs_options, fstopt and mount_by elements
  (bsc#1061289)
- 4.0.0
* Fri Oct  6 2017 jlopez@suse.com
- Added support for reading new format of proposal settings.
- Part of fate#318196.
- 3.3.27
* Thu Oct  5 2017 ancor@suse.com
- Partitioner: don't return to the summary screen after each
  operation.
- Partitioner: speedup the refresh time after each operation (by
  not querying the hostname again).
- Both part of fate#318196.
- 3.3.26
* Wed Oct  4 2017 shundhammer@suse.de
- Added disk.desktop file for partitioner (bsc#1059528)
- 3.3.25
* Wed Oct  4 2017 snwint@suse.com
- separate planning strategies from DevicesPlanner into
  DevicesPlannerStrategies module
- 3.3.24
* Tue Oct  3 2017 ancor@suse.com
- Partitioner: buttons to edit the filesystem in RAID and LVM LV.
- Partitioner: correct positioning of some buttons.
- Partitioner: allow to mount several swap devices.
- All part of fate#318196.
- 3.3.23
* Fri Sep 29 2017 ancor@suse.com
- Partitioner: option to create an MD RAID (part of fate#318196).
- 3.3.22
* Fri Sep 29 2017 jlopez@suse.com
- Fix validation when trying to create a partition with custom
  size (bsc#1060864).
- 3.3.21
* Tue Sep 26 2017 shundhammer@suse.de
- Implemented simple proposal for CASP (bsc#1058736)
- 3.3.20
* Mon Sep 25 2017 snwint@suse.de
- updated installer hacks document: ssh key import works
* Fri Sep 22 2017 jlopez@suse.com
- Avoid to reuse small efi partitions (bsc#1056640).
- 3.3.19
* Thu Sep 21 2017 ancor@suse.com
- More backwards-compatible behavior when formatting partitions in
  the expert partitioner.
- Checkbox to enable snapshots for "/" in the expert partitioner.
- Both part of fate#318196
- 3.3.18
* Tue Sep 19 2017 ancor@suse.com
- Improved creation and modification of partitions in the Expert
  Partitioner (bsc#1057869, bsc#1057874).
- Added button to define the Btrfs subvolumes directly during
  creation or modification.
- 3.3.17
* Wed Sep 13 2017 jreidinger@suse.com
- add all full udev links and helper to list them all
  (useful for fixing bsc#1057604)
- 3.3.16
* Wed Sep 13 2017 snwint@suse.com
- don't limit uefi to x86_64 (bsc#1056629)
- 3.3.15
* Tue Sep 12 2017 jlopez@suse.com
- Fix proposal to not try to create more than 3 partitions in a
  DASD partition table (bsc#1058052).
- 3.3.14
* Thu Sep  7 2017 schubi@suse.de
- AutoYaST: Temporary workaround to avoid crash when size 'auto'
  (which is still not supported) is used (bnc#1056182).
- 3.3.13
* Thu Sep  7 2017 jlopez@suse.com
- Fix partitioner bug creating partition with custom size
  (bsc#1057049)
- 3.3.12
* Thu Sep  7 2017 ancor@suse.com
- AutoYaST: support for Btrfs snapshots (part of fate#318196).
- 3.3.11
* Wed Sep  6 2017 jlopez@suse.com
- Fix bug when formatting with expert partitioner (bsc#1057405).
- 3.3.10
* Wed Sep  6 2017 igonzalezsosa@suse.com
- Ignore case when parsing sizes (bsc#1056715 and bsc#1055913).
- 3.3.9
* Tue Sep  5 2017 schubi@suse.de
- AutoYaST: Handle sizes without unit correctly. (bnc#1056168)
- 3.3.8
* Tue Sep  5 2017 ancor@suse.com
- Create Btrfs in the guided setup if requested to do so (part of
  fate#318196).
- 3.3.7
* Wed Aug 30 2017 jlopez@suse.com
- Added overall summary for the expert partitioner.
- Part of fate#318196
- 3.3.6
* Wed Aug 23 2017 jlopez@suse.com
- Added methods to save user data into libstorage-ng objects.
- Added subvolume shadowing control to the expert partitioner.
- Added mount point validation to the expert partitioner.
- Removed Planned::BtrfsSubvolume class.
- Part of fate#318196
- 3.3.5
* Mon Aug 21 2017 knut.anderssen@suse.com
- Added support for legacy filesystems (fate#323394).
- 3.3.4
* Mon Aug 21 2017 snwint@suse.de
- adjust package description in spec file
* Mon Aug 21 2017 ancor@suse.com
- When displaying partition ids to the user, use names that are
  more similar to old yast-storage (part of fate#318196).
- 3.3.3
* Fri Aug 18 2017 knut.anderssen@suse.com
- ReiserFS is not allowed anymore, it was already removed in SLE 12
  for new installations and was only supported for upgrades.
  (fate#323394)
- 3.3.2
* Wed Aug 16 2017 ancor@suse.com
- Added deactivation of virtual devices (multipath, LVM, etc.)
  to the public API.
- Initial management of Btrfs subvolumes in the expert partitioner.
- Both as part of fate#318196
- 3.3.1
* Mon Jul 24 2017 jlopez@suse.com
- Removed temporary StorageManager API.
- 0.1.32
* Thu Jul 20 2017 ancor@suse.com
- Added pop-up to ask the user about multipath activation.
* Thu Jul 20 2017 ancor@suse.com
- Added Btrfs subvolumes support to the AutoYaST customized
  partitioning.
* Tue Jul 18 2017 ancor@suse.com
- Adjusted the guided proposal to work properly on scenarios with
  DM RAIDs.
* Mon Jul 17 2017 ancor@suse.com
- Adjusted the guided proposal to work properly on scenarios with
  Multipath I/O.
* Wed Jul 12 2017 ancor@suse.com
- Replaced the original prototype of the expert partitioner with
  the one coming from yast2-partitioner.
- Added #supported_fstab_options and #default_partition_id methods
  to Y2Storage::Filesystems::Type.
- Removed Y2Storage::DevicesLists and not longer needed modules
  from Y2Storage::Refinements
- 0.1.31
* Tue Jul 11 2017 jreidinger@suse.com
- Added PartitionId#to_human_string and PartitionId::formattable?
- 0.1.30
* Thu Jul  6 2017 gsouza@suse.com
- Added verifications for disk in network.
- 0.1.29
* Tue Jul  4 2017 jlopez@suse.com
- Added new class Y2Storage::Proposal::Base.
- Proper assignment of default values for new proposals.
- 0.1.28
* Tue Jul  4 2017 ancor@suse.com
- Added AutoinstProfile::PartitioningSection which allows to export
  the current system (or any other devicegraph) to an AutoYaST
  profile (only plain partitions supported so far).
- 0.1.27
* Mon Jul  3 2017 jlopez@suse.com
- Adapt proposal to different situations (disable home, snapshots,
  etc)
- 0.1.26
* Mon Jul  3 2017 jreidinger@suse.com
- add LvmVg#basename
- add PartitionTables::Base#delete_all_partitions
- add logger to all devices
- add LvmVg#name
- 0.1.25
* Tue Jun 27 2017 igonzalezsosa@suse.com
- Add LVM support for AutoYaST partitioning (bsc#1044697).
- 0.1.24
* Tue Jun 27 2017 ancor@suse.com
- More robust Y2Storage::StorageManager#probe
* Mon Jun 26 2017 jreidinger@suse.com
- Added Y2Storage::MdParity#to_human_string and
  Y2Storage::MdLevel#to_human_string
- 0.1.23
* Mon Jun 26 2017 aschnell@suse.com
- Added Y2Storage::Md wrapper
- 0.1.22
* Mon Jun 19 2017 mvidner@suse.com
- Added Y2Storage::DiskSize#human_floor, Y2Storage::Region#size
- 0.1.21
* Mon Jun 19 2017 igonzalezsosa@suse.com
- AutoinstProposal is loaded with the rest of the proposal
  classes when 'y2storage' is required.
- 0.1.20
* Mon Jun 19 2017 jilopez@localhost
- Adjustments to DASD to ensure the proposal works as expected
  in such devices.
- Added Devicegraph#disk_devices to get all DASDs and disks.
- DASD support added to YAML reader and writer.
* Fri Jun 16 2017 igonzalezsosa@suse.com
- Add basic support for AutoYaST customized partitioning
  (only plain partitions are supported)
- 0.1.19
* Thu Jun 15 2017 jreidinger@suse.com
- Add new method StorageManager.fake_from_xml for easy loading
  of xml device graphs
* Wed Jun 14 2017 aschnell@suse.com
- added probe function to StorageManager
- 0.1.18
* Thu Jun  8 2017 ancor@suse.com
- Added new method BlkDevice#to_be_formatted? (needed by
  yast2-partitioner).
- 0.1.17
* Tue Jun  6 2017 shundhammer@suse.de
- Don't insist on installing filesystem support packages that
  are not available in any repo (bsc#1039830)
- 0.1.16
* Thu Jun  1 2017 ancor@suse.com
- Fixed a bug in LvmLv#stripe_size=
* Mon May 22 2017 ancor@suse.com
- Refactored the proposal code in preparation for the AutoYaST
  implementation. Removed PlannedVolume and PlannedVolumesList
  classes in favor of new more specific classes in the Planned
  namespace.
- Fixed the proposal to never propose subvolumes that would be
  shadowed by another proposed device.
* Wed May 17 2017 jreidinger@suse.com
- Add to Y2Storage::PartitionTables::Type#to_human_string
- 0.1.15
* Thu May  4 2017 schubi@suse.de
- Added SCR agent .etc.mtab again until we have a proper
  alternative for it (still needed in yast2-users).
- 0.1.14
* Thu May  4 2017 ancor@suse.com
- Changelog entry to document stuff that was left behind.
  See below.
- Installation proposal now generates Btrfs subvolumes when needed
  (according to control.xml and a fallback list).
- Improved and fully functional Guided Setup.
- Added new fields to ProposalSettings and renamed others (xxx_size
  instead of xxx_disk_size). Similar changes in PlannedVolume.
- New smaller and more convenient API for DiskAnalyzer.
- Many documentation (Yardoc) improvements and fixes.
- Added dummy activate callbacks (for activating a previous LUKS).
- The installer now saves a xml representation of the probed and
  staging devicegraphs before proceeding with the installation.
- New API for accessing the libstorage objects from Ruby:
  * New classes in the Y2Storage namespace offering a wrapper around
    the corresponding libstorage classes and enums: Actiongraph,
    AlignPolicy, BlkDevice, BtrfsSubvolume, Dasd, DasdFormat,
    DasdType, DataTransport, Device, Devicegraph, Disk, Encryption,
    LvmLv, LvmPv, LvmVg, Mountable, Partition, PartitionId,
    PartitionType, Partitionable, Region and ResizeInfo.
  * Mixins StorageClassWrapper and StorageEnumWrapper to define more
    wrappers as needed.
  * Removed EnumMappings.
  * Removed most refinements in Y2Storage, functionality moved to
    the new classes.
  * Marked DevicesList as deprecated.
  * Marked some refinements as deprecated.
* Tue Apr 25 2017 jreidinger@suse.com
- add Gpt#pmbr_boot(?/=) methods for protective MBR
- 0.1.13
* Thu Mar 23 2017 jilopez@localhost
- Adapted prepdisk client to work in update mode.
* Tue Mar 21 2017 schubi@suse.de
- Added to_s in ProposalSettings
* Thu Mar  9 2017 ancor@suse.com
- Partially adjust the proposal settings according to control.xml.
* Fri Mar  3 2017 ancor@suse.com
- Improved the EnumMappings module.
- 0.1.12
* Thu Feb 16 2017 ancor@suse.com
- Improvements in the devicegraph query interface: added an
  EncryptionLists class and adapted all the other classes to take
  several encryption-related scenarios into account.
- 0.1.11
* Wed Feb  8 2017 ancor@suse.com
- Added a prototype of the "Guided Setup" wizard to configure the
  proposal settings.
* Wed Jan 25 2017 ancor@suse.com
- Proper management of completely empty disks (no partition table,
  no file-system and no LVM PV) in the proposal.
- Improved FreeDiskSpace and Disk#free_spaces to correctly handle
  disks without partition table.
- 0.1.10
* Thu Jan 19 2017 shundhammer@suse.de
- Install storage-related software packages as needed: Migrated
  UsedStorageFeatures to storage-ng and added PackageHandler
- 0.1.9
* Tue Jan 17 2017 ancor@suse.com
- Improved StorageManager that complies to the Singleton pattern
  and includes a revision counter for the staging devicegraph.
- 0.1.8
* Mon Jan 16 2017 ancor@suse.com
- Added 'fstab_options' key to the YAML representation of the
  devicegraphs used for testing.
- 0.1.7
* Thu Jan  5 2017 ancor@suse.com
- Y2Storage::DiskAnalyzer - distinguish disks with no MBR gap
  (0 bytes gap) from cases where the MBR gap is not applicable.
  This fixes the proposal for some LVM scenarios with legacy boot.
* Fri Dec 23 2016 ancor@suse.com
- Removed unused ProposalDemo client (kind of obsoleted by
  Dialogs::InstDiskProposal)
* Wed Dec 21 2016 ancor@suse.com
- Improvements in the devicegraph query interface
  (DisksLists#with_name_or_partition)
- 0.1.6
* Tue Dec 20 2016 ancor@suse.com
- Fixed partitioning proposal to not fail when trying to create
  very small partitions (like bios_boot), to work better with uneven
  spaces (not divisible by the minimal grain) and to reduce the
  gaps between partitions.
* Wed Dec 14 2016 ancor@suse.com
- Write more precise information in the logs (DiskSize#to_s)
* Tue Dec 13 2016 ancor@suse.com
- Proposal does not try to set the boot flag if not supported
  (for example, GPT partition tables)
* Fri Dec  9 2016 aschnell@suse.com
- Adapted to several changes in libstorage-ng
* Fri Nov 25 2016 ancor@suse.com
- Improvements in the LVM-based proposal
* Tue Nov 22 2016 ancor@suse.com
- Improvements in Refinements::DevicegraphLists
* Tue Nov 22 2016 ancor@suse.com
- Convenience method to check for GPT
- Several methods added to most of the DevicesLists classes
- 0.1.5
* Thu Oct 27 2016 ancor@suse.com
- Better management of LVM partitions in Proposal::SpaceMaker
* Thu Oct 27 2016 aschnell@suse.com
- mount special filesystems in target during installation
* Wed Oct 26 2016 ancor@suse.com
- LVM classes added to Refinements::DevicegraphLists
* Wed Oct 12 2016 cwh@suse.com
- Use own textdomain (storage-ng instead of storage) (bsc#1004050)
- 0.1.4
* Fri Sep 30 2016 ancor@suse.com
- Added new inst_prepdisk client - first version in which the
  installer commits the changes to the target disk(s).
- 0.1.3
* Tue Sep 27 2016 ancor@suse.com
- More reusable DiskAnalyzer.
- Use libstorage mechanisms to check for windows partitions.
- Added new minimalistic inst_disk_proposal client.
- 0.1.2
* Mon Aug  1 2016 ancor@suse.com
- Namespaces adapted to avoid conflicts with old yast2-storage
  and to follow the new YaST convention.
- 0.1.1
* Thu Feb 25 2016 aschnell@suse.com
- initial package with yast2-storage-ng, successor of yast2-storage
